<?php

namespace App\Console\Commands;

use App\Models\GoldPrices;
use Illuminate\Console\Command;
use App\Models\Golden;
use App\Models\Notifications;
use Goutte\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;

class GoldenHandler extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'cronlive:golden';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'get golden prices';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['app.debug' => true]); 
        $client = new Client();
        $crawler = $client->request('GET', 'https://market.isagha.com/prices');

        $prices = [];

        $crawler->filter('.isagha-panel')->each(function ($node) use (&$prices) {
            $type = $node->filter('.gauge span')->text();
            $sell = $node->filter('.stats .col-xs-4')->eq(0)->filter('.value')->text();
            $buy = $node->filter('.stats .col-xs-4')->eq(1)->filter('.value')->text();

            
            $typeMap = [
                'عيار 24' => 'karat-24',
                'عيار 22' => 'karat-22',
                'عيار 21' => 'karat-21',
                'عيار 18' => 'karat-18',
                'عيار 14' => 'karat-14',
                'عيار 12' => 'karat-12',
                'عيار 9' => 'karat-9',
                'جنيه ذهب' => 'gold-pound',
            ];

            if (array_key_exists(trim($type), $typeMap)) {
                $key = $typeMap[trim($type)];
                $prices[$key] = [
                    'sell' => str_replace(',', '', trim($sell)),
                    'buy' => str_replace(',', '', trim($buy)),
                ];
            }
        });
        
        
        foreach ($prices as $slug => $price) 
        {
            $gold = Golden::where('slug', $slug)->with('rate')->first();
            if (!$gold) continue;

            // check new data
            $sell = $price['sell'];
            $buy  = $price['buy'];
            

            $isUpdate = false;

            if ($sell != $gold->rate->p_price)
            {
                $sellChangeAmount  = ($sell - $gold->rate->p_price);
                $sellStatus        = $sell > $gold->rate->p_price ? 'up' : 'down';
                $sellChangePercent = $sellStatus == 'up' 
                    ? ($sellChangeAmount * 100) / $sell 
                    : ($sellChangeAmount * 100) / $gold->rate->p_price;

                $isUpdate = true;
            }

            if ($buy != $gold->rate->buy_price)
            {
                $buyChangeAmount  = ($buy - $gold->rate->buy_price);
                $buyStatus = $buy > $gold->rate->buy_price ? 'up' : 'down';
                $buyChangePercent = $buyStatus == 'up' 
                    ? ($buyChangeAmount * 100) / $buy
                    : ($buyChangeAmount * 100) / $gold->rate->buy_price;

                // notification
                if ($slug == 'karat-21')
                {
                    $this->publicNotifications($buyStatus, $buy);
                }
                $isUpdate = true;
            }
            
            

            if ($isUpdate === true)
            {

                Cache::forget('eg_local_gold_price');
                
                $dataUpdate = [
                    'p_price' => $sell,
                    'p_status' => $sellStatus,
                    'change_amount' => $sellChangeAmount,
                    'p_status_percentage' => priceFormat($sellChangePercent, 2),
                    'buy_price' => $buy,
                    'buy_status' => $buyStatus,
                    'buy_change_amount' => $buyChangeAmount,
                    'buy_change_percent' => priceFormat($buyChangePercent, 2),
                    'p_last_update' => time()
                ];
                
                GoldPrices::where('p_id', $gold->rate->p_id)->update($dataUpdate);
                // add it in archive
                \DB::table('bp_gold_archive')->insert([
                    [
                        'archive_kind' => $gold->rate->p_kind,
                        'archive_price' => $buy,
                        'price_type' => 'buy',
                        'archive_date' => time()
                    ],
                    [
                        'archive_kind' => $gold->rate->p_kind,
                        'archive_price' => $sell,
                        'price_type' => 'sell',
                        'archive_date' => time()
                    ]
                ]);

                if ($slug == 'karat-24')
                {
                    // ask price
                    $buyOnz  = ($buy * 31.1035);
                    $sellOnz = ($sell * 31.1035);
                    $goldOnz = Golden::where('slug', 'ounce-gold')->with('rate')->first();

                    $sellChangeAmountOnz  = ($sellOnz - $goldOnz->rate->p_price);
                    $sellStatusOnz        = $sellOnz > $goldOnz->rate->p_price ? 'up' : 'down';
                    $sellChangePercentOnz = $sellStatusOnz == 'up' 
                        ? ($sellChangeAmountOnz * 100) / $sellOnz 
                        : ($sellChangeAmountOnz * 100) / $goldOnz->rate->p_price;

                    $buyChangeAmountOnz  = ($buyOnz - $goldOnz->rate->buy_price);
                    $buyStatusOnz = $buyOnz > $goldOnz->rate->buy_price ? 'up' : 'down';
                    $buyChangePercentOnz = $buyStatus == 'up' 
                        ? ($buyChangeAmountOnz * 100) / $buyOnz
                        : ($buyChangeAmountOnz * 100) / $goldOnz->rate->buy_price;

                    $dataUpdateOnz = [
                        'p_price' => $sellOnz,
                        'p_status' => $sellStatusOnz,
                        'change_amount' => $sellChangeAmountOnz,
                        'p_status_percentage' => priceFormat($sellChangePercentOnz, 2),
                        'buy_price' => $buyOnz,
                        'buy_status' => $buyStatusOnz,
                        'buy_change_amount' => $buyChangeAmountOnz,
                        'buy_change_percent' => priceFormat($buyChangePercentOnz, 2),
                        'p_last_update' => time()
                    ];
                    GoldPrices::where('p_id', 7)->update($dataUpdateOnz);

                    \DB::table('bp_gold_archive')->insert([
                        [
                            'archive_kind' => 7,
                            'archive_price' => $buyOnz,
                            'price_type' => 'buy',
                            'archive_date' => time()
                        ],
                        [
                            'archive_kind' => 7,
                            'archive_price' => $sellOnz,
                            'price_type' => 'sell',
                            'archive_date' => time()
                        ]
                    ]);
                }




            }
        }
        return;

    }

    private function getFromGoldPriceToday()
    {
        $Content = (getCrul('https://egypt.gold-price-today.com/'));
        // create new DOMDocument
        $document = new \DOMDocument('1.0', 'UTF-8');
        // set error level
        $internalErrors = libxml_use_internal_errors(true);
        // load HTML
        $document->loadHTML($Content);
        $xpath = new \DOMXPath($document);
        $row = $xpath->query("//*[contains(@class, 'prices-table')]");
        $i = 1;
        $row = $row->item(0);

        foreach($row->getElementsByTagName('tr') as $index => $tr)
        {
            if ( $index == 0 )
                continue;

                try {
                  $kind  = $tr->getElementsByTagName('th')->item(0)->nodeValue;
                } catch (\Exception $e) {
                    echo ($e->getMessage());
                    continue;
                }
                
                list($buy, $buyPrice, $sell, $sellPrice) = explode(' ', $tr->getElementsByTagName('td')->item(0)->nodeValue);
                // dump($buy);
                // dump($buyPrice);
                // dump($sell);
                // dd($sellPrice);
                $price = number_format((int)str_replace(',', '',trim($sellPrice)), 2, '.', '');
                // get id of this kind
                $kind_id = $i;
                $i++;
                // check if this price with this kind is same in db or not
                $data_2 = \DB::table('bp_gold_price')->where('p_kind', $kind_id)->first();
                $data_2 = (array)$data_2;
                if ( empty($data_2) ){
                    continue;
                  // insert it
                  $upGold = ['p_price'=> $price, 'p_last_update' => time(), 'p_kind' => $kind_id];
                  \DB::table('bp_gold_price')->insert($upGold);
                  continue;
                }

                if ( null !== $data_2 && $data_2['p_price'] == $price)
                {
                    continue;
                }elseif ( null !== $data_2 && $data_2['p_price'] != $price)
                {
                    $status = $data_2['p_status'];
                    $change_percent = $data_2['p_status_percentage'];
                    $change_amount  = $data_2['change_amount'];

                    if ( $price < $data_2['p_price'] )
                    {
                        $change_amount   = $price - $data_2['p_price'];
                        $change_percent   = ($change_amount * 100) / $data_2['p_price'];
                        $status = 'down';

                    }elseif ( $price > $data_2['p_price'] )
                    {
                        $change_amount   = $price - $data_2['p_price'];
                        $change_percent   = ($change_amount * 100) / $price;
                        $status = 'up';
                    }

                    // 21 carat
                    if ($kind_id == 3)
                    {
                       $this->publicNotifications($status, $price);
                    }
                    
                    // update it
                    $upGold = ['p_price'=> $price, 'p_last_update' => time(), 'p_status' => $status, 'p_status_percentage' => rounded($change_percent), 'change_amount' => rounded($change_amount)];


                    \DB::table('bp_gold_price')->where('p_kind', $kind_id)->update($upGold);

                    // and add it in archive
                     \DB::table('bp_gold_archive')->insert(
                       ['archive_kind'=> $kind_id, 'archive_price'=> $price, 'archive_date' => time()]
                     );

                    echo 'DONE';
                    echo "\n\r";
                }
        }
    }



    private function publicNotifications($status, $price)
    {
        if ($status == 'up')
        {
        $title_ar = 'أرتفاع سعر الذهب عيار 21 جرام الي  ' . $price;
        $title_en = 'The price of 21-carat gold has increased to ' . $price;
        }else{
        $title_ar = 'إنخفاض سعر الذهب عيار 21 جرام الي  ' . $price;
        $title_en = 'Decrease in the price of 21-karat gold to ' . $price;
        }

        

        $notifications = New Notifications();
        $notifications->title_ar = $title_ar;
        $notifications->title_en = $title_en;
        $notifications->device_type = 'all';
        $notifications->link = 'https://banklive.net/gold-price-today-in-egypt';
        $notifications->link_en = 'https://banklive.net/en/gold-price-today-in-egypt';
        $notifications->to_key = 'gold';
        $notifications->save();
    }

}
