<?php

namespace App\Console;

use App\Jobs\GetExchangeRateJob;
use App\Jobs\GetMetalGlobalRateJob;
use App\Models\Currencies;
use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;

class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
      'App\Console\Commands\BanksHandler',
      'App\Console\Commands\GoldenHandler',
      'App\Console\Commands\SilverHandler',
      'App\Console\Commands\BanksIsLost',
      'App\Console\Commands\getGeneralCurrency',
      'App\Console\Commands\scrapPetrolEg',
      'App\Console\Commands\MobileAppNotifications',
      'App\Console\Commands\FBMessengerNoti',
      'App\Console\Commands\PublishOnSocial',
      'App\Console\Commands\Notifications',
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule  $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {
        $schedule->command('queue:work --stop-when-empty')->everyMinute();

        $schedule->call(function () {
            $currencies = ['EGP', 'USD', 'SAR'];
            $delay = 2; // تأخير زمني بين كل طلب (ثواني)
            foreach ($currencies as $index => $currency) {
                GetMetalGlobalRateJob::dispatch($currency)->delay(now()->addSeconds($index * $delay));
            }
        })->everyMinute();
        
        $schedule->call(function () {
            $delay = 3;
            $currenciesMain = ['EGP', 'USD', 'SAR'];
            foreach ($currenciesMain as $key => $currency)
            {
                GetExchangeRateJob::dispatch($currency)
                ->delay(now()->addSeconds($key * $delay));
            }
        })->everyMinute();


        $schedule->call(function () {
            $currenciesMain = ['EGP', 'USD', 'SAR'];
            $delay = 1;
            $bankCurrencies = Currencies::select('cur_code')
            ->whereNotIn('cur_code', $currenciesMain)
            ->where('cur_banks_support', 1)->get();
            foreach ($bankCurrencies as $key => $currency) 
            {
                GetExchangeRateJob::dispatch($currency->cur_code)
                ->delay(now()->addSeconds(($key + count($currenciesMain)) * $delay));
            }
        })->everyFiveMinutes();


        $schedule->call(function () {
            $currenciesMain = ['EGP', 'USD', 'SAR'];
            $delay = 1;
            $allCurrencies = Currencies::select('cur_code')
            ->where('cur_banks_support', 0)
            ->where('is_lost', 0)
            ->whereNotIn('cur_code', $currenciesMain)->get();
            foreach ($allCurrencies as $key => $currency) 
            {
                GetExchangeRateJob::dispatch($currency->cur_code)
                ->delay(now()->addSeconds(($key + count($currenciesMain)) * $delay));
            }
        })->everyFiveMinutes();
        
    }

    /**
     * Register the commands for the application.
     *
     * @return void
     */
    protected function commands()
    {
        $this->load(__DIR__.'/Commands');

        require base_path('routes/console.php');
    }


    /**
     * Get the timezone that should be used by default for scheduled events.
     *
     * @return \DateTimeZone|string|null
     */
    protected function scheduleTimezone()
    {
        return 'Africa/Cairo';
    }

}
