<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Banks;
use App\Models\Query;
use App\Models\Currencies;
use App\Models\GoldPrices;
use \Carbon\Carbon;
class HomeController extends Controller
{

  public function getCurencyRates($cur_code)
  {
    // check this Currency
    $currency = Query::getCurrRatesWithBanks($cur_code);

    if ( null === $currency )
        return response()->json(['status' => false, 'data' => 'not found this currency']);

        $returnData['currency_code'] = $currency['cur_code'];
        $returnData['currency_ar']   = $currency['cur_name_ar'];
        $returnData['currency_en']   = $currency['cur_name_en'];
        $curLastChangeDate = timeago($currency['cur_last_update']);
        $returnData['currency_last_change_str'] = 'منذ '  . $curLastChangeDate;
        $returnData['currency_last_change'] = Carbon::createFromTimestamp($currency['cur_last_update'])->toDateTimeString();

        // handle bank rates
        for( $i = 0, $counter = count($currency['rates']); $i < $counter; $i++  )
        {

            // bank info
            $returnData['rates'][$i]['bank_id']      = $currency['rates'][$i]['bankp_bank_id'];
            $returnData['rates'][$i]['bank_name_ar'] = $currency['rates'][$i]['bank_name_ar'];
            $returnData['rates'][$i]['bank_name_en'] = $currency['rates'][$i]['bank_name_en'];
            $returnData['rates'][$i]['bank_logo_slug'] = $currency['rates'][$i]['bank_image'];
            $returnData['rates'][$i]['bank_logo'] = $this->convertImageToBase64(('uploads/35x35/' . $currency['rates'][$i]['bank_image']));

            // buy price status
            $returnData['rates'][$i]['buy_price'] = rounded($currency['rates'][$i]['bankp_buy_banknote']);
            $returnData['rates'][$i]['change_buy_price_status'] = $currency['rates'][$i]['bankp_status_buy'];
            $returnData['rates'][$i]['change_buy_price_percent'] = $currency['rates'][$i]['bankp_percent_buy'];

            // sell price status
            $returnData['rates'][$i]['sell_price'] = rounded($currency['rates'][$i]['bankp_sell_banknote']);
            $returnData['rates'][$i]['change_sell_price_status'] = $currency['rates'][$i]['bankp_status_sell'];
            $returnData['rates'][$i]['change_sell_price_percent'] = $currency['rates'][$i]['bankp_percent_sell'];

        }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method


  public function getBestPricesToday($cur = null)
  {
    if ( $cur === null )
        $allHomePrices = Query::get_best_prices(['usd', 'eur', 'sar'], 1);
    else
    {
       $allHomePrices  = Currencies::where('cur_code', $cur)->first();
       if ( $allHomePrices === null )
            return response()->json(['status' => false, 'data' => 'we can not found this currency']);


       $allHomePrices = Query::get_best_prices([ strtolower($allHomePrices->cur_code) ], 1);
    }

    foreach($allHomePrices as $currencyHome)
    {


        $returnData['currency_code'] = $currencyHome['cur_code'];
        $returnData['currency_ar']   = $currencyHome['cur_name_ar'];
        $returnData['currency_en']   = $currencyHome['cur_name_en'];

        // start buy status
        $returnData['best_buy']['bank_id'] = $currencyHome['buy'][0]['bankp_bank_id'];
        $returnData['best_buy']['bank_name_ar'] = $currencyHome['buy'][0]['bank_name_ar'];
        $returnData['best_buy']['bank_name_en'] = $currencyHome['buy'][0]['bank_name_en'];
        $returnData['best_buy']['price'] = rounded($currencyHome['buy'][0]['bankp_buy_banknote']);
        $returnData['best_buy']['change_price_status'] = $currencyHome['buy'][0]['bankp_status_buy'];
        $returnData['best_buy']['change_price_percent'] = $currencyHome['buy'][0]['bankp_percent_buy'];

        $buyLastChangeDate = timeago($currencyHome['buy'][0]['bankp_update']);
        $returnData['best_buy']['currency_last_change_str']= 'منذ '  . $buyLastChangeDate;
        $returnData['best_buy']['currency_last_change']= Carbon::createFromTimestamp($currencyHome['buy'][0]['bankp_update'])->toDateTimeString();
        $returnData['best_buy']['bank_logo_slug'] = $currencyHome['buy'][0]['bank_image'];
        $returnData['best_buy']['bank_logo']      = $this->convertImageToBase64(('uploads/35x35/' . $currencyHome['buy'][0]['bank_image']));

        // start sell status
        $returnData['best_sell']['bank_id'] = $currencyHome['sell'][0]['bankp_bank_id'];
        $returnData['best_sell']['bank_name_ar'] = $currencyHome['sell'][0]['bank_name_ar'];
        $returnData['best_sell']['bank_name_en'] = $currencyHome['sell'][0]['bank_name_en'];
        $returnData['best_sell']['price'] = rounded($currencyHome['sell'][0]['bankp_sell_banknote']);
        $returnData['best_sell']['change_price_status'] = $currencyHome['sell'][0]['bankp_status_sell'];
        $returnData['best_sell']['change_price_percent'] = $currencyHome['sell'][0]['bankp_percent_sell'];

        $sellLastChangeDate = timeago($currencyHome['sell'][0]['bankp_update']);
        $returnData['best_sell']['currency_last_change_str'] = 'منذ '  . $sellLastChangeDate;
        $returnData['best_sell']['currency_last_change'] = Carbon::createFromTimestamp($currencyHome['sell'][0]['bankp_update'])->toDateTimeString();
        $returnData['best_sell']['bank_logo_slug'] = $currencyHome['sell'][0]['bank_image'];
        $returnData['best_sell']['bank_logo']      = $this->convertImageToBase64(('uploads/35x35/' . $currencyHome['sell'][0]['bank_image']));


    }// end of foreach
    return response()->json(['status' => true, 'data' => ['currency' => $returnData]]);
  } // end of method



  public function getBankRates($bank_id)
  {

    // check if found this bank or not
    $bank = Banks::where('active', 1)->where('bank_id', $bank_id)->first();
    if ( null === $bank )
        return response()->json(['status' => false, 'data' => 'not found this bank']);

    // get all currencies rates
    $BPrices = Query::getCurrRatesByBank($bank['bank_slug']);

    // handle bank info
    $returnData['id'] = $BPrices['bank_id'];
    $returnData['name_ar'] = $BPrices['bank_name_ar'];
    $returnData['name_en'] = $BPrices['bank_name_en'];
    $bankLastChangeDate = timeago($BPrices['bank_last_update']);
    $returnData['last_change_str'] = 'منذ '  . $bankLastChangeDate;
    $returnData['last_change'] = Carbon::createFromTimestamp($BPrices['bank_last_update'])->toDateTimeString();
    $returnData['bank_logo_slug'] = $BPrices['bank_image'];
    $returnData['bank_logo'] = $this->convertImageToBase64(('uploads/35x35/' . $BPrices['bank_image']));

    // handle bank rates
    for( $i = 0, $counter = count($BPrices['rates']); $i < $counter; $i++  )
    {
        $returnData['rates'][$i]['currency_code'] = $BPrices['rates'][$i]['cur_code'];
        $returnData['rates'][$i]['currency_ar'] = $BPrices['rates'][$i]['cur_name_ar'];
        $returnData['rates'][$i]['currency_en'] = $BPrices['rates'][$i]['cur_name_en'];
        $CurLastChangeDate = timeago($BPrices['rates'][$i]['bankp_update']);
        $returnData['rates'][$i]['currency_last_change_str'] = 'منذ '  . $CurLastChangeDate;
        $returnData['rates'][$i]['currency_last_change'] = Carbon::createFromTimestamp($BPrices['rates'][$i]['bankp_update'])->toDateTimeString();

        // buy price status
        $returnData['rates'][$i]['buy_price'] = rounded($BPrices['rates'][$i]['bankp_buy_banknote']);
        $returnData['rates'][$i]['change_buy_price_status'] = $BPrices['rates'][$i]['bankp_status_buy'];
        $returnData['rates'][$i]['change_buy_price_percent'] = $BPrices['rates'][$i]['bankp_percent_buy'];


        // sell price status
        $returnData['rates'][$i]['sell_price'] = rounded($BPrices['rates'][$i]['bankp_sell_banknote']);
        $returnData['rates'][$i]['change_sell_price_status'] = $BPrices['rates'][$i]['bankp_status_sell'];
        $returnData['rates'][$i]['change_sell_price_percent'] = $BPrices['rates'][$i]['bankp_percent_sell'];


    }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method




  public function getGoldenPrice()
  {

    $allGoldenPrices = GoldPrices::with('kind')->get();
    $returnData = [];
    for( $i = 0, $counter = count($allGoldenPrices); $i < $counter; $i++  )
    {
        $returnData[$i]['gold_type_ar'] = $allGoldenPrices[$i]->kind->g_name_ar;
        $returnData[$i]['gold_type_en'] = $allGoldenPrices[$i]->kind->g_name_en;
        $returnData[$i]['gold_price']   = rounded($allGoldenPrices[$i]->p_price);
        $LastChangeDate = timeago($allGoldenPrices[$i]['p_last_update']);
        $returnData[$i]['gold_last_change_str'] = 'منذ '  . $LastChangeDate;
        $returnData[$i]['gold_last_change'] = Carbon::createFromTimestamp($allGoldenPrices[$i]['p_last_update'])->toDateTimeString();
        $returnData[$i]['gold_status'] = $allGoldenPrices[$i]->p_status;
        $returnData[$i]['gold_status_price'] = $allGoldenPrices[$i]->p_status_percentage;
    }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method



  public function getAllCurrencies()
  {

    $allCurencies = Currencies::select(['cur_code', 'cur_name_ar', 'cur_name_en', 'cur_last_update'])->where('cur_banks_support', 1)->get();

    $returnData = [];
    for( $i = 0, $counter = count($allCurencies); $i < $counter; $i++  )
    {
        $returnData[$i]['currency_code'] = $allCurencies[$i]['cur_code'];
        $returnData[$i]['currency_ar'] = $allCurencies[$i]['cur_name_ar'];
        $returnData[$i]['currency_en'] = $allCurencies[$i]['cur_name_en'];
        $CurLastChangeDate = timeago($allCurencies[$i]['cur_last_update']);
        $returnData[$i]['currency_last_change_str'] = 'منذ '  . $CurLastChangeDate;
        $returnData[$i]['currency_last_change'] = Carbon::createFromTimestamp($allCurencies[$i]['cur_last_update'])->toDateTimeString();
    }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method



  public function getAllBanks()
  {

    $allBanks    = Banks::select(['bank_id', 'bank_name_ar', 'bank_name_en', 'bank_last_update', 'bank_image'])->where('active', 1)->get();
    $returnBanks = [];
    for( $i = 0, $banksCount = count($allBanks); $i < $banksCount; $i++  )
    {
        $returnBanks[$i]['id'] = $allBanks[$i]['bank_id'];
        $returnBanks[$i]['name_ar'] = $allBanks[$i]['bank_name_ar'];
        $returnBanks[$i]['name_en'] = $allBanks[$i]['bank_name_en'];
        $bankLastChangeDate = timeago($allBanks[$i]['bank_last_update']);
        $returnBanks[$i]['last_change_str'] = 'منذ '  . $bankLastChangeDate;
        $returnBanks[$i]['last_change'] = Carbon::createFromTimestamp($allBanks[$i]['bank_last_update'])->toDateTimeString();
        $returnBanks[$i]['bank_logo_slug'] = $allBanks[$i]['bank_image'];
        $returnBanks[$i]['bank_logo'] = $this->convertImageToBase64(('uploads/35x35/' . $allBanks[$i]['bank_image']));
    }

    return response()->json(['status' => true, 'data' => $returnBanks]);
  }// end of method

   protected function convertImageToBase64($imagePath)
   {
        return url('public/' . $imagePath);
        /*
        $type = pathinfo($imagePath, PATHINFO_EXTENSION);
        $data = file_get_contents($imagePath);
        return 'data:image/' . $type . ';base64,' . base64_encode($data);
        */
   } // end of method


  public function checkAppUpdate()
  {
    $resultAppUpdate = [
        'v_code'    => '1.0.9',
        'message'   => 'أحنا حدثنا تطبيق بنك لايف مصر وبقى أفضل واسرع وأكثر أماناً .. احذف الإصدار ده وحمل الجديد ;)',
        'periority' => 'high', // low
    ];
    return response()->json($resultAppUpdate);
  }// end of method




}
