<?php

namespace App\Http\Controllers\Api\v2;

use App\Http\Controllers\Api\v2\ApiService;
use Illuminate\Http\Request;
use App\Models\Banks;
use App\Models\Query;
use App\Models\Currencies;
use App\Models\CurrenciesPrices;
use App\Models\GoldPrices;
use \Carbon\Carbon;

class AuthApplicationController extends ApiService
{
  // get all banks
  public function index()
  {
    $banks  = Banks::select(['bank_id', 'bank_name_ar', 'bank_name_en', 'bank_last_update', 'bank_image'])->where('active', 1)->where('is_lost', 0)->orderByRaw('bank_sort=0,bank_sort asc')->get();
    $rBanks = [];

    foreach ($banks as $key => $bank) 
    {
      $rBanks[$key]['id'] = $bank->bank_id;
      $rBanks[$key]['name'] = trim($bank->name);
      $rBanks[$key]['bank_logo_slug'] = $bank->bank_image;
      $rBanks[$key]['bank_logo'] = url(('uploads/35x35/' . $bank->bank_image));
      $rBanks[$key]['updated_at_humans'] = Carbon::createFromTimestamp($bank->bank_last_update)->diffForHumans();
      $rBanks[$key]['updated_at'] = Carbon::createFromTimestamp($bank->bank_last_update)->toDateTimeString();
    }

    return ApiService::generateNewResponse($rBanks);
  }// end of method


// get bankInfo & rates
public function getBankRates($bank_id)
{
  $bank  = Banks::select([
    'bank_id', 
    'bank_url', 
    'bank_hotline', 
    'bank_name_ar', 
    'bank_name_en', 
    'bank_fb',
    'bank_last_update',
    'bank_image'])->where('active', 1)->where('is_lost', 0)->where('bank_id', $bank_id)->first();

    if ($bank === Null)
      return ApiService::generateNewResponse('', false, 404, 'BANK_NOT_AVALIBLE');


    $bankInfo = [];
    $bankInfo['id']                = $bank->bank_id;
    $bankInfo['name']              = ($bank->name);
    $bankInfo['bank_url']          = trim($bank->bank_url);
    $bankInfo['bank_hotline']      = trim($bank->bank_hotline);
    $bankInfo['bank_fb']           = trim($bank->bank_fb);
    $bankInfo['bank_logo_slug']    = $bank->bank_image;
    $bankInfo['bank_logo']         = url(('uploads/35x35/' . $bank->bank_image));
    $bankInfo['updated_at_humans'] = Carbon::createFromTimestamp($bank->bank_last_update)->diffForHumans();
    $bankInfo['updated_at']        = Carbon::createFromTimestamp($bank->bank_last_update)->toDateTimeString();

    $bankRates  = CurrenciesPrices::selectRaw('bp_bank_price.bankp_cur_id,bp_bank_price.bankp_sell_banknote,bp_bank_price.bankp_buy_banknote, bp_bank_price.bankp_status_buy, bp_bank_price.bankp_status_sell,bp_bank_price.buy_change_amount, bp_bank_price.sell_change_amount, bp_bank_price.buy_change_percent, bp_bank_price.sell_change_percent, bp_bank_price.bankp_update,bp_currencies.cur_id,bp_currencies.cur_name_en, bp_currencies.cur_name_ar, bp_currencies.cur_flag')
                       ->join('bp_currencies', 'bp_currencies.cur_id', '=', 'bp_bank_price.bankp_cur_id')
                      ->where('bankp_bank_id', $bank->bank_id)
                      ->orderBy('bp_currencies.cur_sort', 'asc')
                      ->get(); 
    foreach ($bankRates as $key => $currencyRate) {
      
      $bankInfo['rates'][$key]['currency_id']       = $currencyRate->currency->cur_id;
      $bankInfo['rates'][$key]['currency_name']     = trim($currencyRate->currency->name);
      $bankInfo['rates'][$key]['currency_flag']     = $currencyRate->currency->cur_flag;
      $bankInfo['rates'][$key]['currency_flag_url'] = url($currencyRate->currency->smallflag);
      $bankInfo['rates'][$key]['rate_updated_at_humans'] = Carbon::createFromTimestamp($currencyRate->bankp_update)->diffForHumans();
      $bankInfo['rates'][$key]['rate_updated_at'] = Carbon::createFromTimestamp($currencyRate->bankp_update)->toDateTimeString();

      // // buy price status
      $bankInfo['rates'][$key]['buy']['price'] = rounded($currencyRate->bankp_buy_banknote);
      $bankInfo['rates'][$key]['buy']['change_status'] = !empty($currencyRate->bankp_status_buy) ? $currencyRate->bankp_status_buy : 'equal';
      $bankInfo['rates'][$key]['buy']['change_percent'] = $currencyRate->buy_change_percent . '%';
      $bankInfo['rates'][$key]['buy']['change_amount'] = $currencyRate->buy_change_amount;


      // // sell price status
      $bankInfo['rates'][$key]['sell']['price'] = rounded($currencyRate->bankp_sell_banknote);
      $bankInfo['rates'][$key]['sell']['bankp_status'] = !empty($currencyRate->bankp_status_sell) ? $currencyRate->bankp_status_sell : 'equal';
      $bankInfo['rates'][$key]['sell']['change_percent'] = $currencyRate->sell_change_percent . '%';
      $bankInfo['rates'][$key]['sell']['change_amount'] = $currencyRate->sell_change_amount;

    }
    return ApiService::generateNewResponse($bankInfo);
}// end of method

  public function getCurencyRates($cur_code)
  {
    // check this Currency
    $currency = Query::getCurrRatesWithBanks($cur_code);

    if ( null === $currency )
        return response()->json(['status' => false, 'data' => 'not found this currency']);

        $returnData['currency_code'] = $currency['cur_code'];
        $returnData['currency_ar']   = $currency['cur_name_ar'];
        $returnData['currency_en']   = $currency['cur_name_en'];
        $curLastChangeDate = timeago($currency['cur_last_update']);
        $returnData['currency_last_change_str'] = 'منذ '  . $curLastChangeDate;
        $returnData['currency_last_change'] = Carbon::createFromTimestamp($currency['cur_last_update'])->toDateTimeString();

        // handle bank rates
        for( $i = 0, $counter = count($currency['rates']); $i < $counter; $i++  )
        {

            // bank info
            $returnData['rates'][$i]['bank_id']      = $currency['rates'][$i]['bankp_bank_id'];
            $returnData['rates'][$i]['bank_name_ar'] = $currency['rates'][$i]['bank_name_ar'];
            $returnData['rates'][$i]['bank_name_en'] = $currency['rates'][$i]['bank_name_en'];
            $returnData['rates'][$i]['bank_logo_slug'] = $currency['rates'][$i]['bank_image'];
            $returnData['rates'][$i]['bank_logo'] = url(('uploads/35x35/' . $currency['rates'][$i]['bank_image']));

            // buy price status
            $returnData['rates'][$i]['buy']['price'] = rounded($currency['rates'][$i]['bankp_buy_banknote']);
            $returnData['rates'][$i]['buy']['change_price_status'] = $currency['rates'][$i]['bankp_status_buy'];
            $returnData['rates'][$i]['buy']['change_price_percent'] = $currency['rates'][$i]['bankp_percent_buy'];

            // sell price status
            $returnData['rates'][$i]['sell']['price'] = rounded($currency['rates'][$i]['bankp_sell_banknote']);
            $returnData['rates'][$i]['sell']['change_price_status'] = $currency['rates'][$i]['bankp_status_sell'];
            $returnData['rates'][$i]['sell']['change_price_percent'] = $currency['rates'][$i]['bankp_percent_sell'];

        }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method


  public function getBestPricesToday($cur = null)
  {
    config(['app.debug' => true]);
    if ( $cur === null )
        $allHomePrices = Query::get_best_prices(['usd', 'eur', 'sar'], 1);
    else
    {
       $allHomePrices  = Currencies::where('cur_code', $cur)->first();
       if ( $allHomePrices === null )
            return response()->json(['status' => false, 'data' => 'we can not found this currency']);


       $allHomePrices = Query::get_best_prices([ strtolower($allHomePrices->cur_code) ], 1);
    }

    foreach($allHomePrices as $currencyHome)
    {


        $returnData['currency_code'] = $currencyHome['cur_code'];
        $returnData['currency_ar']   = $currencyHome['cur_name_ar'];
        $returnData['currency_en']   = $currencyHome['cur_name_en'];

        // start buy status
        $returnData['best_buy']['bank_id'] = $currencyHome['buy'][0]['bankp_bank_id'];
        $returnData['best_buy']['bank_name_ar'] = $currencyHome['buy'][0]['bank_name_ar'];
        $returnData['best_buy']['bank_name_en'] = $currencyHome['buy'][0]['bank_name_en'];
        $returnData['best_buy']['price'] = rounded($currencyHome['buy'][0]['bankp_buy_banknote']);
        $returnData['best_buy']['change_price_status'] = $currencyHome['buy'][0]['bankp_status_buy'];
        $returnData['best_buy']['change_price_percent'] = $currencyHome['buy'][0]['bankp_percent_buy'];

        $buyLastChangeDate = timeago($currencyHome['buy'][0]['bankp_update']);
        $returnData['best_buy']['currency_last_change_str']= 'منذ '  . $buyLastChangeDate;
        $returnData['best_buy']['currency_last_change']= Carbon::createFromTimestamp($currencyHome['buy'][0]['bankp_update'])->toDateTimeString();
        $returnData['best_buy']['bank_logo_slug'] = $currencyHome['buy'][0]['bank_image'];
        $returnData['best_buy']['bank_logo']      = $this->convertImageToBase64(('uploads/35x35/' . $currencyHome['buy'][0]['bank_image']));

        // start sell status
        $returnData['best_sell']['bank_id'] = $currencyHome['sell'][0]['bankp_bank_id'];
        $returnData['best_sell']['bank_name_ar'] = $currencyHome['sell'][0]['bank_name_ar'];
        $returnData['best_sell']['bank_name_en'] = $currencyHome['sell'][0]['bank_name_en'];
        $returnData['best_sell']['price'] = rounded($currencyHome['sell'][0]['bankp_sell_banknote']);
        $returnData['best_sell']['change_price_status'] = $currencyHome['sell'][0]['bankp_status_sell'];
        $returnData['best_sell']['change_price_percent'] = $currencyHome['sell'][0]['bankp_percent_sell'];

        $sellLastChangeDate = timeago($currencyHome['sell'][0]['bankp_update']);
        $returnData['best_sell']['currency_last_change_str'] = 'منذ '  . $sellLastChangeDate;
        $returnData['best_sell']['currency_last_change'] = Carbon::createFromTimestamp($currencyHome['sell'][0]['bankp_update'])->toDateTimeString();
        $returnData['best_sell']['bank_logo_slug'] = $currencyHome['sell'][0]['bank_image'];
        $returnData['best_sell']['bank_logo']      = $this->convertImageToBase64(('uploads/35x35/' . $currencyHome['sell'][0]['bank_image']));


    }// end of foreach
    return response()->json(['status' => true, 'data' => ['currency' => $returnData]]);
  } // end of method








  public function getGoldenPrice()
  {

    $allGoldenPrices = GoldPrices::with('kind')->get();
    $returnData = [];
    for( $i = 0, $counter = count($allGoldenPrices); $i < $counter; $i++  )
    {
        $returnData[$i]['gold_type_ar'] = $allGoldenPrices[$i]->kind->g_name_ar;
        $returnData[$i]['gold_type_en'] = $allGoldenPrices[$i]->kind->g_name_en;
        $returnData[$i]['gold_price']   = rounded($allGoldenPrices[$i]->p_price);
        $LastChangeDate = timeago($allGoldenPrices[$i]['p_last_update']);
        $returnData[$i]['gold_last_change_str'] = 'منذ '  . $LastChangeDate;
        $returnData[$i]['gold_last_change'] = Carbon::createFromTimestamp($allGoldenPrices[$i]['p_last_update'])->toDateTimeString();
        $returnData[$i]['gold_status'] = $allGoldenPrices[$i]->p_status;
        $returnData[$i]['gold_status_price'] = $allGoldenPrices[$i]->p_status_percentage;
    }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method



  public function getAllCurrencies()
  {

    $allCurencies = Currencies::select(['cur_code', 'cur_name_ar', 'cur_name_en', 'cur_last_update'])->get();

    $returnData = [];
    for( $i = 0, $counter = count($allCurencies); $i < $counter; $i++  )
    {
        $returnData[$i]['currency_code'] = $allCurencies[$i]['cur_code'];
        $returnData[$i]['currency_ar'] = $allCurencies[$i]['cur_name_ar'];
        $returnData[$i]['currency_en'] = $allCurencies[$i]['cur_name_en'];
        $CurLastChangeDate = timeago($allCurencies[$i]['cur_last_update']);
        $returnData[$i]['currency_last_change_str'] = 'منذ '  . $CurLastChangeDate;
        $returnData[$i]['currency_last_change'] = Carbon::createFromTimestamp($allCurencies[$i]['cur_last_update'])->toDateTimeString();
    }

    return response()->json(['status' => true, 'data' => $returnData]);
  } // end of method





  //  protected function url($imagePath)
  //  {
  //       return url('public/' . $imagePath);
  //       /*
  //       $type = pathinfo($imagePath, PATHINFO_EXTENSION);
  //       $data = file_get_contents($imagePath);
  //       return 'data:image/' . $type . ';base64,' . base64_encode($data);
  //       */
  //  } // end of method


  public function checkAppUpdate()
  {
    $resultAppUpdate = [
        'v_code'    => '1.8',
        'message'   => 'برجاء تحميل الإصدار الجديد من تطبيق بنك لايف',
        'periority' => 'low', // low
    ];
    return response()->json($resultAppUpdate);
  }// end of method




}
