<?php

namespace App\Http\Controllers\Api\v2;

use App\Http\Controllers\Api\v2\ApiService;
use App\Models\Banks;
use App\Models\CurrenciesPrices;
use \Carbon\Carbon;

class BanksController extends ApiService
{
  // get all banks
  public function index()
  {
    $banks  = Banks::select(['bank_id', 'bank_name_ar', 'bank_name_en', 'bank_last_update', 'bank_image'])->where('active', 1)->where('is_lost', 0)->orderByRaw('bank_sort=0,bank_sort asc')->get();
    $rBanks = [];

    foreach ($banks as $key => $bank) 
    {
      $rBanks[$key]['id'] = $bank->bank_id;
      $rBanks[$key]['name'] = trim($bank->name);
      $rBanks[$key]['bank_logo_slug'] = $bank->bank_image;
      $rBanks[$key]['bank_logo'] = url(('uploads/35x35/' . $bank->bank_image));
      $rBanks[$key]['updated_at_humans'] = Carbon::createFromTimestamp($bank->bank_last_update)->diffForHumans();
      $rBanks[$key]['updated_at'] = Carbon::createFromTimestamp($bank->bank_last_update)->toDateTimeString();
    }

    return ApiService::generateNewResponse($rBanks);
  }// end of method


// get bankInfo & rates
public function getBankRates($bank_id)
{
  $bank  = Banks::select([
    'bank_id', 
    'bank_url', 
    'bank_hotline', 
    'bank_name_ar', 
    'bank_name_en', 
    'bank_fb',
    'bank_last_update',
    'bank_image'])->where('active', 1)->where('is_lost', 0)->where('bank_id', $bank_id)->first();

    if ($bank === Null)
      return ApiService::generateNewResponse('', false, 404, 'BANK_NOT_AVALIBLE');


    $bankInfo = [];
    $bankInfo['id']                = $bank->bank_id;
    $bankInfo['name']              = ($bank->name);
    $bankInfo['bank_url']          = trim($bank->bank_url);
    $bankInfo['bank_hotline']      = trim($bank->bank_hotline);
    $bankInfo['bank_fb']           = trim($bank->bank_fb);
    $bankInfo['bank_logo_slug']    = $bank->bank_image;
    $bankInfo['bank_logo']         = url(('uploads/420x420/' . $bank->bank_image));
    $bankInfo['updated_at_humans'] = Carbon::createFromTimestamp($bank->bank_last_update)->diffForHumans();
    $bankInfo['updated_at']        = Carbon::createFromTimestamp($bank->bank_last_update)->toDateTimeString();

    $bankRates  = CurrenciesPrices::selectRaw('bp_bank_price.bankp_cur_id,bp_bank_price.bankp_sell_banknote,bp_bank_price.bankp_buy_banknote, bp_bank_price.bankp_status_buy, bp_bank_price.bankp_status_sell,bp_bank_price.buy_change_amount, bp_bank_price.sell_change_amount, bp_bank_price.buy_change_percent, bp_bank_price.sell_change_percent, bp_bank_price.bankp_update,bp_currencies.cur_id,bp_currencies.cur_name_en, bp_currencies.cur_name_ar, bp_currencies.cur_flag')
                       ->join('bp_currencies', 'bp_currencies.cur_id', '=', 'bp_bank_price.bankp_cur_id')
                      ->where('bankp_bank_id', $bank->bank_id)
                      ->orderBy('bp_currencies.cur_sort', 'asc')
                      ->get(); 
    foreach ($bankRates as $key => $currencyRate) {
      
      $bankInfo['rates'][$key]['currency_id']       = $currencyRate->currency->cur_id;
      $bankInfo['rates'][$key]['currency_name']     = trim($currencyRate->currency->name);
      $bankInfo['rates'][$key]['currency_flag']     = $currencyRate->currency->cur_flag;
      $bankInfo['rates'][$key]['currency_flag_url'] = url($currencyRate->currency->smallflag);
      $bankInfo['rates'][$key]['rate_updated_at_humans'] = Carbon::createFromTimestamp($currencyRate->bankp_update)->diffForHumans();
      $bankInfo['rates'][$key]['rate_updated_at'] = Carbon::createFromTimestamp($currencyRate->bankp_update)->toDateTimeString();

      // // buy price status
      $bankInfo['rates'][$key]['buy']['price'] = rounded($currencyRate->bankp_buy_banknote);
      $bankInfo['rates'][$key]['buy']['change_status'] = !empty($currencyRate->bankp_status_buy) ? $currencyRate->bankp_status_buy : 'equal';
      $bankInfo['rates'][$key]['buy']['change_percent'] = $currencyRate->buy_change_percent . '%';
      $bankInfo['rates'][$key]['buy']['change_amount'] = $currencyRate->buy_change_amount;


      // // sell price status
      $bankInfo['rates'][$key]['sell']['price'] = rounded($currencyRate->bankp_sell_banknote);
      $bankInfo['rates'][$key]['sell']['bankp_status'] = !empty($currencyRate->bankp_status_sell) ? $currencyRate->bankp_status_sell : 'equal';
      $bankInfo['rates'][$key]['sell']['change_percent'] = $currencyRate->sell_change_percent . '%';
      $bankInfo['rates'][$key]['sell']['change_amount'] = $currencyRate->sell_change_amount;

    }
    return ApiService::generateNewResponse($bankInfo);
}// end of method


  public function checkAppUpdate()
  {
    $resultAppUpdate = [
        'v_code'    => '1.8',
        'message'   => 'برجاء تحميل الإصدار الجديد من تطبيق بنك لايف',
        'periority' => 'low', // low
    ];
    return response()->json($resultAppUpdate);
  }// end of method




}
