<?php

namespace App\Http\Controllers\Api\v2;

use App\Http\Controllers\Api\v2\ApiService;
use App\Models\Currencies;
use App\Models\CurrenciesPrices;
use App\Models\GeneralCurrencyRates;
use \Carbon\Carbon;

class CurrenciesController extends ApiService
{
  // get all banks
  public function index()
  {
    $currencies = Currencies::select(['cur_id','cur_banks_support', 'cur_flag', 'cur_code', 'cur_name_ar', 'cur_name_en', 'cur_last_update', 'cur_sort'])->where('is_active', 1)->orderByRaw('cur_sort = 0, cur_sort asc')->get();

    $rCurrencies = []; 
    foreach ($currencies as $key => $currency) 
    {
        $rCurrencies[$key]['id'] = $currency->cur_id;
        $rCurrencies[$key]['cur_sort'] = $currency->cur_sort;
        $rCurrencies[$key]['code'] = $currency->cur_code;
        $rCurrencies[$key]['name'] = $currency->name;
        $rCurrencies[$key]['supported_in_eg_banks'] = $currency->cur_banks_support == 1 ?? false;
        $rCurrencies[$key]['supported_in_eg_banks_txt'] = $currency->cur_banks_support == 1 ? __('main.supported') : __('main.nonsupported');
        $rCurrencies[$key]['currency_flag_slug'] = $currency->cur_flag;
        $rCurrencies[$key]['currency_flag'] = url($currency->smallflag);
        $rCurrencies[$key]['updated_at_humans'] = Carbon::createFromTimestamp($currency->cur_last_update)->diffForHumans();
        $rCurrencies[$key]['updated_at'] = Carbon::createFromTimestamp($currency->cur_last_update)->toDateTimeString();
    }

    return ApiService::generateNewResponse($rCurrencies);
  }// end of method


    // get bankInfo & rates
    public function getCurrencyRates($currency_id)
    {
        // get currency info 
            // name
            // falg
            // code
        $currency = Currencies::select(['cur_id','cur_banks_support', 'cur_flag', 'cur_code', 'cur_name_ar', 'cur_name_en', 'cur_last_update'])->where('is_active', 1)->where('cur_id', $currency_id)->first();

        if ($currency === Null)
            return ApiService::generateNewResponse('', false, 404, 'CURRENCY_NOT_AVALIBLE');


        if ($currency->cur_banks_support == 0)
            return $this->generalCurrencyRates($currency);

        $rCurrency['currency_info'] = [];
        $rCurrency['currency_info']['id'] = $currency->cur_id;
        $rCurrency['currency_info']['code'] = $currency->cur_code;
        $rCurrency['currency_info']['name'] = $currency->name;
        $rCurrency['currency_info']['supported_in_eg_banks'] = $currency->cur_banks_support == 1 ?? False;
        $rCurrency['currency_info']['supported_in_eg_banks_txt'] = $currency->cur_banks_support == 1 ? __('main.supported') : __('main.nonsupported');
        $rCurrency['currency_info']['currency_flag_slug'] = $currency->cur_flag;
        $rCurrency['currency_info']['currency_flag'] = url($currency->smallflag);
        $rCurrency['currency_info']['updated_at_humans'] = Carbon::createFromTimestamp($currency->cur_last_update)->diffForHumans();
        $rCurrency['currency_info']['updated_at'] = Carbon::createFromTimestamp($currency->cur_last_update)->toDateTimeString();



        // get best buy and best sell
        $bestBuy = CurrenciesPrices::selectRaw('bankp_bank_id,bankp_buy_banknote,bankp_status_buy,buy_change_amount,buy_change_percent,bp_bank_price.updated_at,bp_banks.bank_id,bp_banks.bank_name_ar,bp_banks.bank_name_en,bp_banks.bank_image')
        ->join('bp_banks', 'bp_banks.bank_id', '=', 'bankp_bank_id')
        ->where('bp_banks.active', 1)
        ->where('bp_banks.is_lost', 0)
        ->where('bp_bank_price.is_active', 1)
        ->where('bankp_cur_id', $currency->cur_id)
        ->where('bankp_buy_banknote', '!=', 0)
        ->orderBy('bankp_buy_banknote', 'desc')
        ->first(); 
        $rCurrency['best_buy']['bank_id']           = ''.$bestBuy->bank_id.'';
        $rCurrency['best_buy']['bank_name']         = $bestBuy->bank->name;
        $rCurrency['best_buy']['price']             = rounded($bestBuy->bankp_buy_banknote);
        $rCurrency['best_buy']['change_status']     = rounded($bestBuy->bankp_status_buy);
        $rCurrency['best_buy']['change_amount']     = rounded($bestBuy->buy_change_amount);
        $rCurrency['best_buy']['change_percent']    = rounded($bestBuy->buy_change_percent);
        $rCurrency['best_buy']['bank_logo_slug']    = $bestBuy->bank_image;
        $rCurrency['best_buy']['bank_logo']         = url(('uploads/35x35/' . $bestBuy->bank_image));
        // $rCurrency['best_buy']['updated_at_humans'] = Carbon::createFromTimestamp($bestBuy->updated_at)->diffForHumans();
        // $rCurrency['best_buy']['updated_at']        = Carbon::createFromTimestamp($bestBuy->updated_at)->toDateTimeString();

        $bestSell = CurrenciesPrices::selectRaw('bankp_bank_id,bankp_sell_banknote,bankp_status_sell,sell_change_amount,sell_change_percent,bp_bank_price.updated_at,bp_banks.bank_id,bp_banks.bank_name_ar,bp_banks.bank_name_en,bp_banks.bank_image')
        ->join('bp_banks', 'bp_banks.bank_id', '=', 'bankp_bank_id')
        ->where('bp_banks.active', 1)
        ->where('bp_banks.is_lost', 0)
        ->where('bp_bank_price.is_active', 1)
        ->where('bankp_cur_id', $currency->cur_id)
        ->where('bankp_sell_banknote', '!=', 0)
        ->where('bankp_sell_banknote', '>', $bestBuy->bankp_buy_banknote)
        ->orderBy('bankp_sell_banknote', 'asc')
        ->first();

        $rCurrency['best_sell']['bank_id']           = ''.$bestSell->bank_id.'';
        $rCurrency['best_sell']['bank_name']         = $bestSell->bank->name;
        $rCurrency['best_sell']['price']             = rounded($bestSell->bankp_sell_banknote);
        $rCurrency['best_sell']['change_status']     = rounded($bestSell->bankp_status_sell);
        $rCurrency['best_sell']['change_amount']     = ($bestSell->sell_change_amount);
        $rCurrency['best_sell']['change_percent']    = ($bestSell->sell_change_percent);
        $rCurrency['best_sell']['bank_logo_slug']    = $bestSell->bank_image;
        $rCurrency['best_sell']['bank_logo']         = url(('uploads/35x35/' . $bestSell->bank_image));



    
        $ratesOnBanks = CurrenciesPrices::selectRaw('bankp_bank_id,bankp_buy_banknote,bankp_status_buy,buy_change_amount,buy_change_percent,bankp_sell_banknote,bankp_status_sell,sell_change_amount,sell_change_percent,bp_banks.updated_at,bp_banks.bank_id,bp_banks.bank_name_ar,bp_banks.bank_name_en,bp_banks.bank_image')
        ->join('bp_banks', 'bp_banks.bank_id', '=', 'bankp_bank_id')
        ->where('bp_banks.active', 1)
        ->where('bp_banks.is_lost', 0)
        ->where('bp_bank_price.is_active', 1)
        ->where('bankp_cur_id', $currency->cur_id)
        ->where('bankp_buy_banknote', '!=', 0)
        ->where('bankp_sell_banknote', '!=', 0)
        ->orderBy('bankp_buy_banknote', 'desc')
        ->get(); 

        $rCurrency['rates_banks'] = [];
        foreach ($ratesOnBanks as $key => $ratesOnBank) 
        {

            
            $rCurrency['rates_banks'][$key]['bank_info']['bank_id']           = "$ratesOnBank->bank_id";
            $rCurrency['rates_banks'][$key]['bank_info']['bank_name']         = $ratesOnBank->bank->name;
            $rCurrency['rates_banks'][$key]['bank_info']['bank_logo_slug']    = $ratesOnBank->bank_image;
            $rCurrency['rates_banks'][$key]['bank_info']['bank_logo']         = url(('uploads/35x35/' . $ratesOnBank->bank_image));
            $rCurrency['rates_banks'][$key]['bank_info']['updated_at_txt']    = Carbon::parse($ratesOnBank->updated_at)->diffForHumans();
            $rCurrency['rates_banks'][$key]['bank_info']['updated_at']        = Carbon::parse($ratesOnBank->updated_at)->toDateTimeString();

            $rCurrency['rates_banks'][$key]['buy']['buy_price']             = rounded($ratesOnBank->bankp_buy_banknote);
            $rCurrency['rates_banks'][$key]['buy']['buy_change_status']     = ($ratesOnBank->bankp_status_buy);
            $rCurrency['rates_banks'][$key]['buy']['buy_change_amount']     = ($ratesOnBank->buy_change_amount);
            $rCurrency['rates_banks'][$key]['buy']['buy_change_percent']    = ($ratesOnBank->buy_change_percent);

            $rCurrency['rates_banks'][$key]['sell']['sell_price']             = rounded($ratesOnBank->bankp_sell_banknote);
            $rCurrency['rates_banks'][$key]['sell']['sell_change_status']     = ($ratesOnBank->bankp_status_sell);
            $rCurrency['rates_banks'][$key]['sell']['sell_change_amount']     = ($ratesOnBank->sell_change_amount);
            $rCurrency['rates_banks'][$key]['sell']['sell_change_percent']    = ($ratesOnBank->sell_change_percent);
        }

        return ApiService::generateNewResponse($rCurrency);
    }// end of method


    public function generalCurrencyRates(object $currency)
    {
        $rCurrency['currency_info'] = [];
        $rCurrency['currency_info']['id'] = $currency->cur_id;
        $rCurrency['currency_info']['code'] = $currency->cur_code;
        $rCurrency['currency_info']['name'] = $currency->name;
        $rCurrency['currency_info']['supported_in_eg_banks'] = $currency->cur_banks_support == 1 ?? False;
        $rCurrency['currency_info']['supported_in_eg_banks_txt'] = $currency->cur_banks_support == 1 ? __('main.supported') : __('main.nonsupported');
        $rCurrency['currency_info']['currency_flag_slug'] = $currency->cur_flag;
        $rCurrency['currency_info']['currency_flag'] = url($currency->smallflag);
        $rCurrency['currency_info']['updated_at_humans'] = Carbon::today()->diffForHumans();
        $rCurrency['currency_info']['updated_at'] = Carbon::today()->toDateTimeString();
        // general price of this currency
        $rates = GeneralCurrencyRates::select(['current_price', 'change_status' ,'change_percent', 'change_amount', 'updated_at'])->where('from_cur_id', $currency->cur_id)->where('to_cur_id', 50)->first();

        $rCurrency['rate'] = [
            'price' =>  priceFormat($rates->current_price) . __('main.egCurr'),
            'change_status' =>  ($rates->change_status),
            'change_percent' =>  '('. priceFormat($rates->change_percent) . '%)',
            'change_amount' =>  priceFormat($rates->change_amount),
        ];

        $rCurrency['best_buy']    = null;
        $rCurrency['best_sell']   = null;
        $rCurrency['rates_banks'] = null;

        return ApiService::generateNewResponse($rCurrency);
    }

}