<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Banks;
use App\Models\Currencies;
use App\Models\Query;
use App\Models\Archive;
use App\Models\CurrenciesPrices;
use App\Models\GeneralCurrencyRates;
use Carbon\Carbon;



class BanksController extends Controller
{

  public function index ()
  {

    $rates = collect(Query::getAllBankRates());
    
    // $banks = Banks::where('active', 1)->get();
    return view('index.all_banks')->with('rates', $rates);
  }

  public function showBankData($slug)
  {

    $slugNum = (int) $slug; // old version
    if( is_integer($slugNum) && $slugNum !== 0)
    {
      $bank = Banks::where('active', 1)->findOrFail($slugNum);
      return redirect(bank_url($bank), 301);
    }
    ///////////////////////////////////////////////////////////
    $BPrices = Query::getCurrRatesByBank($slug);
    if ( is_null($BPrices) )
      return redirect('/', 301);

    return view('index.bank')->with(compact('BPrices'));

  }// end of bank data

  public function showBankCurrency($bankSlug, $currencyCode)
  {
    // $currencyCode = str_replace('egp', '', $currency);

    // get bank Info
    $bank = Banks::where('active', 1)->where('is_lost', 0)->where('bank_slug', $bankSlug)->first();
    if (null === $bank)
      return redirect('/', 301);

    // get currency info in this bank
    $currency = Currencies::where('cur_code', strtoupper($currencyCode))->where('cur_banks_support', 1)->first();
    if (null === $currency)
      return redirect('/', 301);

    // get rates info 
    $currencyRateInBank = $currency->bankRate($bank->bank_id);

    
    // get all currencies in this bank
    // $allCurrenciesRatesInBank = Query::getCurrRatesByBank($bankSlug);

    $generalRates = GeneralCurrencyRates::select('current_price', 'change_status','change_percent','change_amount')->where('from_cur_id', $currency->cur_id)->first();

    
    $morePrices = Banks::whereHas('currencyPrices', function ($query) use ($currency, $bank) {
      $query->where('bankp_cur_id', $currency->cur_id)
            ->where('bankp_bank_id', '!=', $bank->bank_id);
  })->with(['currencyPrices' => function ($query) use ($currency, $bank) {
      $query->where('bankp_cur_id', $currency->cur_id)
            ->where('bankp_bank_id', '!=', $bank->bank_id);
  }])
    ->where('active', 1)->where('is_lost', 0)->limit(5)->orderByDesc('updated_at')->get();



    
    // $previousClosures 
    $previousClosures = Archive::whereDate('created_at', '<', $currencyRateInBank->updated_at)
                        ->where('a_bank_id', $bank->bank_id)
                        ->where('a_curn_id', $currency->cur_id)
                        ->where('a_option', 'buy')
                        ->where('a_price', '!=', $currencyRateInBank->bankp_buy_banknote)
                        ->orderBy('created_at', 'desc')
                        ->first();
                        
    $previousClosuresPrice = [];
    $previousClosuresPrice['price'] = $previousClosures->a_price;
    $previousClosuresPrice['change_amount'] = $currencyRateInBank->bankp_buy_banknote - $previousClosures->a_price;
    $previousClosuresPrice['change_percent'] = ($currencyRateInBank->bankp_buy_banknote - $previousClosures->a_price) / $previousClosures->a_price * 100;
    $previousClosuresPrice['change_percent'] = number_format($previousClosuresPrice['change_percent'], 2);
    $previousClosuresPrice['status'] = $previousClosuresPrice['change_amount'] < 0 ? 'down' : 'up';
    
    $previousClosuresPrice = (object) ($previousClosuresPrice);
    // // get all archive by filter
    $filter = request('days');
    $filter = isset($filter) ? $filter : 90;
    
    if (in_array($filter, [1,7,30]))
      $getArchivePrices = Archive::getArchivePrices($bank->bank_id, $currency->cur_id, 'buy', $filter, 'days');
    elseif(in_array($filter, [90,180]))
      $getArchivePrices = Archive::getArchivePrices($bank->bank_id, $currency->cur_id, 'buy', $filter, 'months');
    elseif(in_array($filter, [365,'all']))
      $getArchivePrices = Archive::getArchivePrices($bank->bank_id, $currency->cur_id, 'buy', $filter, 'years');
    else
      $getArchivePrices = Archive::getArchivePrices($bank->bank_id, $currency->cur_id, 'buy', 30, 'days');
    
      
      $BPrices = Query::getCurrRatesByBank($bank->bank_slug);

    return view('index.bank_currency_rate')
            ->with('currency', $currency)
            ->with('bank', $bank)
            ->with('filter', $filter)
            ->with('currencyRateInBank', $currencyRateInBank)
            ->with('previousClosuresPrice', $previousClosuresPrice)
            ->with('generalRates', $generalRates)
            ->with('morePrices', $morePrices)
            ->with('getArchivePrices', $getArchivePrices)
            ->with('BPrices', $BPrices);
  }

}
