<?php

namespace App\Http\Controllers;

use App\Models\Golden;
use App\Models\PetroleumTypes;
use App\Models\Silver;
use Illuminate\Http\Request;
use \App\Models\Query;
use SEO;
use App\BrowserTokensFCM;
use App\Models\Banks;
use App\Models\Currencies;
use GuzzleHttp\Client;
use App\Models\GeneralCurrencyRates;
use App\Models\Pages;
use Illuminate\Support\Facades\Cache;
use Artesaos\SEOTools\Facades\JsonLd;
use Artesaos\SEOTools\Facades\SEOMeta;
use Artesaos\SEOTools\Facades\SEOTools;
use Artesaos\SEOTools\Facades\OpenGraph;
use Illuminate\Support\Facades\URL;


class Home extends Controller
{

	public $data = [];

    public function getShortPrice(Request $request)
    {
			if( $request->ajax() )
			{
				$best_prices = Query::get_best_prices(['usd', 'sar', 'eur','kwd','qar'], 1);
				return view('includes.home_best_prices')->with('currencies', $best_prices);
			}// end of check ajax
    }
    
    

	public function index()
	{
        // Cache::forget('eg_local_petrol_price');
        $GeneralCurrencyRates = Cache::remember('eg_local_banks_rates', 6000000, function () {
            $getCurrency = Currencies::select('cur_id')->where('cur_banks_support', 0)->where('is_lost', 0)->limit(8)->get()->pluck('cur_id')->toArray();
             return GeneralCurrencyRates::selectRaw('current_price,change_status,change_amount,change_percent,from_cur_id')
            ->whereIn('from_cur_id', $getCurrency)->where('to_cur_id', 50)->with('currency')->limit(8)->get();
            });



        $rates = Cache::remember('eg_local_home_banks_prices', 6000000, function () {
            return collect(Query::getAllBankRates(10));
        });

        

        $goldPrice = Cache::remember('eg_local_gold_price', 6000000, function () {
            return Golden::whereIn('g_id', [1,3,4,7])->with('price')->get();
        });
        
        $silverPrice = Cache::remember('eg_local_silver_price', 6000000, function () {
            return Silver::whereIn('s_id', [1,3,4,7])->with('price')->get();
        });
        
        $petroleumPrice = Cache::remember('eg_local_petrol_price', 6000000,function () {
            return PetroleumTypes::with('rate')->limit(5)->get();
        });
        
        $banks =  Cache::remember('eg_local_home_banks', 6000000,function () {
            return Banks::where('active', 1)->orderByDesc('updated_at')->limit(9)->get();
        });
        

        // <!-- Site Description -->
        // {!! SEOMeta::generate() !!}
        // {!! OpenGraph::generate() !!}
        // {!! Twitter::generate() !!}
        // {!! JsonLd::generate() !!}
        $settings = config('mainSettings');
        $siteName = $settings['site_name_en'];
        $siteMiniDesc = $settings['site_mini_desc_en'];
        $siteDesc = $settings['site_desc_en'];
        if (\LaravelLocalization::getCurrentLocale() == 'ar') {
            $siteName = $settings['site_name_ar'];
            $siteMiniDesc = $settings['site_mini_desc_ar'];
            $siteDesc = $settings['site_desc_ar'];
        }
        
        // OpenGraph::setTitle($siteName . ' - ' . $siteMiniDesc);
        // OpenGraph::setDescription($siteDesc);
        // OpenGraph::setUrl(URL::full());
        // OpenGraph::addImage([url($settings['site_cover']), 'size' => 300]);
        // SEOTools::setTitle($siteName . ' - ' . $siteMiniDesc);
        // SEOTools::setDescription($siteDesc);


        // SEOMeta::setTitle($siteName . ' - ' . $siteMiniDesc);
        // SEOMeta::setDescription($siteDesc);
        // SEOMeta::addMeta('article:section', $siteName . ' - ' . $siteMiniDesc, 'property');
        // SEOMeta::addKeyword([$settings['site_keywords']]);

        

        return view('index.home')
        ->with('rates', $rates)
        ->with('goldPrice', $goldPrice)
        ->with('banks', $banks)
        ->with('silverPrice', $silverPrice)
        ->with('petroleumPrice', $petroleumPrice)
        ->with('GeneralCurrencyRates', $GeneralCurrencyRates);
	}// end of home



    public function show_page($slug)
    {
        $page = Pages::where('page_active', 1)->where('page_slug', $slug)->first();
        if ( null === $page )
            return abort(404);

        return view('index.page', compact('page'));
    }// end of page


		public function contact(Request $request)
		{
            config(['app.debug' => true]);
			if ( $request->isMethod('post') )
			{

                $request->validate([
                    'g-recaptcha-response' => 'required',
                    // 'phone' => 'required|string|max:15',
                    'name' => 'required|max:100',
                    'email' => 'required|email||max:100',
                    'message' => 'required|max:1000',
                ]);
             
                       
                    $client = new Client(); //GuzzleHttp\Client
                    $result = $client->post('https://www.google.com/recaptcha/api/siteverify', [
                        'form_params' => [
                            'secret'   => '6LeQHAQjAAAAANmQtjoCR6ca8aZcSyvZQcbFrJc1',
                            'response' => request()->post('g-recaptcha-response')
                        ]
                    ]);

                    $body = json_decode((string)$result->getBody(), true);
                   
                    if ( $body['success'] == 'true' )
                    {
                       
                        \DB::table('contact_us')->insert([
    						'name'     => $request->name,
    						// 'phone'    => $request->phone,
    						'email'    => $request->email,
    						'content'  => $request->message,
    						'ip'       => request()->ip(),
    					]);

                    \Mail::send([], [], function ($message) use($request)
                    {
                          $message->to(['m.gamalayoub@gmail.com'])
                            ->from('no-replay@banklive.net', 'BankLive | FX Rates')
                            ->subject('banklive New Message From | '. $request->name .' - ' . $request->email)
                            ->html("<div style='text-align: left;'>from : {$request->name} <br />email from : {$request->email} <br /> content : {$request->message}</div>", 'text/html'); // for HTML rich messages

                    }); 
    					return back()->with('success', __('main.contact_sent'));

                    }else{
                        if (isset($body['error-codes']))
                            return back()->with('error', 'recaptcha is ' . $body['error-codes'][0]);
                        else
                            return back()->with('error', 'Error in ReCaptcha');
                    }
			}

			return view('index.contact_page')->with('title', __('main.contact_page_title'));
		}

    public function saveTokenFCM(request $request)
    {
        $token = $request->token;
        if ( $request->ajax() )
        {
            $BrowserTokensFCM = BrowserTokensFCM::where('token_id', $token)->first();

            if ( $BrowserTokensFCM === null )
            {
                $BrowserTokensFCM = new BrowserTokensFCM;
                $BrowserTokensFCM->token_id = $token;
                $BrowserTokensFCM->lang = app()->getLocale();
                $BrowserTokensFCM->ip = $request->ip();
            }else{
                $BrowserTokensFCM->lang = app()->getLocale();
                $BrowserTokensFCM->ip = $request->ip();
            }

            $agent = new \Jenssegers\Agent\Agent;
            $platform = $agent->platform();
            $version = $agent->version($platform);
            $browser = $agent->browser();

            $BrowserTokensFCM->platform = $platform . ' ' . $version;
            $BrowserTokensFCM->browser  = $browser;
            
            $BrowserTokensFCM->save();
            return response()->json(['status' => true]);
        }
    }
}
