<?php

namespace App\Jobs;

use App\Models\Currencies;
use App\Models\GeneralCurrencyRates;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class GetExchangeRateJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;
    protected $baseCurrency;
    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct($currencyCode)
    {
        $this->baseCurrency = $currencyCode;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $this->exchangeRate($this->baseCurrency);
    }

    public function exchangeRate($baseCurrency = 'USD')
    {
        $baseCurrency = strtoupper($baseCurrency);
        $fx = $this->liveMetalPrices($baseCurrency);
        $fx = json_decode($fx, true);
  
        if (!isset($fx['baseCurrency']) || $baseCurrency != $fx['baseCurrency'] || isset($fx['message']) || !isset($fx['rates']))
        {
            return null;
        }


        try {
            $currenciesRates = collect($fx['rates'])
            ->map(function ($item) {
                return $this->handlerPrice($item);
            })
            ->toArray();
        } catch (\Throwable $th) {
            dump($fx);
            dd($th->getMessage());
        }

        if (!isset($currenciesRates)) {
            return;
        }

        $baseCurrency = Currencies::where('cur_code', $baseCurrency)->first();
        $toBaseCurrencyId = $baseCurrency->cur_id;

        $foundUpdate = false;

        foreach ($currenciesRates as $currency_code => $value) {
            if (empty($value) || $value == 0 || $value == 'null')
                continue;

            $value = str_replace(',', '',$value);
            // get currency id
            $currency = Currencies::where('cur_code', $currency_code)->first();
            // dd($currency);

            if ($currency === null) {
                continue;
            }

            // get currency rates
            $currency_rates = GeneralCurrencyRates::where('from_cur_id', $currency->cur_id)
                ->where('to_cur_id', $toBaseCurrencyId)
                ->first();

            // $cost = (100 / $value) / 100;
            $cost = rtrim($value, '0');
            // $cost = number_format ( $cost, 3);

            // $cost         = number_format ( round( $value, 3) , 3);
            $oldCost = $currency_rates->current_price ?? 0;
            $changeAmount = 0;
            $calPercent = 0;

            if (null === $currency_rates) {
                $currency_rates = new GeneralCurrencyRates();
                $currency_rates->from_cur_id = $currency->cur_id;
                $currency_rates->to_cur_id = $toBaseCurrencyId;
                $currency_rates->current_price = $cost;
                $currency_rates->previous_price = 0;
                $currency_rates->change_status = 'up';
                $currency_rates->change_percent = 100;
                $currency_rates->change_amount = $cost;
                $currency_rates->save();
                $currency->cur_last_update = (int) time();
                $currency->save();
            }

            if ($cost == $currency_rates->current_price) {
                continue;
            }

            $changeAmount = $cost - $currency_rates->current_price;

            if ($cost < $currency_rates->current_price) {
                $calPercent = $cost - $currency_rates->current_price;
                $calPercent = ($calPercent * 100) / $currency_rates->current_price;
                $changeStatus = 'down';
                $foundUpdate = true;
            } elseif ($cost > $currency_rates->current_price) {
                $calPercent = $cost - $currency_rates->current_price;
                $calPercent = ($calPercent * 100) / $cost;
                $changeStatus = 'up';
                $foundUpdate = true;
            }

            if ($foundUpdate === true) {
                // save data
                $currency_rates->from_cur_id = $currency->cur_id;
                $currency_rates->to_cur_id = $toBaseCurrencyId;
                $currency_rates->current_price = $cost;
                $currency_rates->previous_price = $oldCost;
                $currency_rates->change_status = $changeStatus;
                $currency_rates->change_percent = $calPercent;
                $currency_rates->change_amount = $changeAmount;
                $currency_rates->save();

                $currency->cur_last_update = (int) time();
                $currency->save();
            }
            $foundUpdate = false;
        }
    }


    private function liveMetalPrices($from = 'EGP', $to = null)
    {
        $curl = curl_init();
        $to = $to != null ? $to : 'AED,AFN,ALL,AMD,ANG,AOA,ARS,AUD,AWG,AZN,BAM,BBD,BDT,BGN,BHD,BIF,BMD,BND,BOB,BRL,BSD,BTN,BWP,BYN,BZD,CAD,CDF,CHF,CLP,CNY,COP,CRC,CUC,CUP,CVE,CZK,DJF,DKK,DOP,DZD,EEK,EGP,ERN,ETB,EUR,FJD,FKP,GBP,GEL,GHS,GIP,GMD,GNF,GTQ,GYD,HKD,HNL,HRK,HTG,HUF,IDR,IMP,INR,IQD,IRR,ISK,JMD,JOD,JPY,KES,KGS,KHR,KMF,KPW,KRW,KWD,KYD,KZT,LAK,LBP,LKR,LRD,LSL,LTL,LYD,MAD,MDL,MGA,MKD,MMK,MNT,MOP,MRU,MTL,MUR,MVR,MWK,MXN,MYR,MZN,NAD,NGN,NIO,NOK,NPR,NZD,OMR,PAB,PEN,PGK,PHP,PKR,PLN,PYG,QAR,RON,RSD,RUB,RWF,SAR,SBD,SCR,SDG,SEK,SGD,SHP,SLL,SOS,SRD,SVC,SYP,SZL,THB,TJS,TMT,TND,TOP,TRY,TTD,TWD,TZS,UAH,UGX,USD,UYU,UZS,VND,XAF,XCD,XOF,XPF,YER,ZAR,ZMW';
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://live-metal-prices.p.rapidapi.com/v1/latest/{$to}/{$from}",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'GET',
            CURLOPT_HTTPHEADER => ['X-RapidAPI-Host: live-metal-prices.p.rapidapi.com', 'X-RapidAPI-Key: d808683ce3mshc0b04186ba5e0f1p1d2e0fjsnc70fc9f2201c'],
        ]);

        $response = curl_exec($curl);
        // $err = curl_error($curl);

        curl_close($curl);

        return $response;
    }

    private function handlerPrice($price)
    {
        $pureRate = 100 / $price / 100;
        $intval = intval($pureRate);

        if ($intval != 0) {
            // return '-';
            return number_format($pureRate, 2);
        }

        $new = number_format($pureRate, 2);
        if ($new < 0.009) {
            $new = number_format($pureRate, 4);
        } elseif ($new < 0.0008) {
            $new = number_format($pureRate, 5);
        } elseif ($new < 0.08) {
            $new = number_format($pureRate, 3);
        }

        return $new;
    }

    // function priceFormatMain($price, $mark = 5) {
    //     if ($price == 0) {
    //         return '0.00';
    //     }
        
    //     // تقريب الرقم إلى العلامة المحددة
    //     $roundedPrice = round($price, $mark);
    //     $formattedPrice = number_format($roundedPrice, $mark, '.', '');
    
    //     // استخراج الجزء العشري
    //     $parts = explode('.', $formattedPrice);
    //     $decimalPart = isset($parts[1]) ? rtrim($parts[1], '0') : '';
    //     $decimalPartCheck = trim($decimalPart, 0);

    //     // التحقق من طول الجزء العشري وتقليله إذا لزم الأمر
    //     if (strlen($decimalPartCheck) >= 3) {
    //         $formattedPrice = $this->priceFormatMain($price, $mark - 1);
    //     } else {
    //         // التأكد من أن الناتج يحتوي على رقمين عشريين على الأقل
    //         if (strlen($decimalPartCheck) < 2) {
    //             $decimalPart = str_pad($decimalPart, 2, '0');
    //         }
    //         $formattedPrice = $parts[0] . '.' . $decimalPart;
    //     }
    
    //     return $formattedPrice;
    // }  
}
