<?php

namespace App\Jobs;

use App\Models\MetalPrices;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class GetMetalGlobalRateJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    protected $baseCurrency;


    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct($currencyCode)
    {
        $this->baseCurrency = $currencyCode;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $fx = $this->liveMetalPrices($this->baseCurrency, 'XAU,XAG,PA,PL');
        $fx = json_decode($fx, true);
        
        if (!isset($fx['rates']))
        return;

        $foundUpdate = false;
        foreach ($fx['rates'] as $key => $newPrice) {
            $oldRecord = MetalPrices::where(['metal_type' => $key, 'currency' => $this->baseCurrency])->first();

            if ($oldRecord) {
                $changeAmount = $newPrice - $oldRecord->price;
                if ($newPrice < $oldRecord->price) {
                    $changePercent = $newPrice - $oldRecord->price;
                    $changePercent = ($changePercent * 100) / $oldRecord->price;
                    $changeStatus = 'down';
                    $foundUpdate = true;
                } elseif ($newPrice > $oldRecord->price) {
                    $changePercent = $newPrice - $oldRecord->price;
                    $changePercent = ($changePercent * 100) / $newPrice;
                    $changeStatus = 'up';
                    $foundUpdate = true;
                }

                if ($foundUpdate) {
                    MetalPrices::updateOrInsert(
                        ['metal_type' => $key, 'currency' => $this->baseCurrency],
                        [
                            'price' => $newPrice,
                            'change_status' => $changeStatus,
                            'change_amount' => number_format($changeAmount, 3),
                            'change_percent' => number_format($changePercent, 3),
                            'currency' => $this->baseCurrency,
                        ],
                    );
                }
            } else {
                MetalPrices::create([
                    'metal_type' => $key,
                    'price' => $newPrice,
                    'change_status' => null,
                    'change_amount' => null,
                    'change_percent' => null,
                    'currency' => $this->baseCurrency,
                ]);
            }
        }
    }


    private function liveMetalPrices($from = 'EGP', $to = null)
    {
        $curl = curl_init();
        $to = $to != null ? $to : 'AED,AFN,ALL,AMD,ANG,AOA,ARS,AUD,AWG,AZN,BAM,BBD,BDT,BGN,BHD,BIF,BMD,BND,BOB,BRL,BSD,BTN,BWP,BYN,BZD,CAD,CDF,CHF,CLP,CNY,COP,CRC,CUC,CUP,CVE,CZK,DJF,DKK,DOP,DZD,EEK,EGP,ERN,ETB,EUR,FJD,FKP,GBP,GEL,GHS,GIP,GMD,GNF,GTQ,GYD,HKD,HNL,HRK,HTG,HUF,IDR,IMP,INR,IQD,IRR,ISK,JMD,JOD,JPY,KES,KGS,KHR,KMF,KPW,KRW,KWD,KYD,KZT,LAK,LBP,LKR,LRD,LSL,LTL,LYD,MAD,MDL,MGA,MKD,MMK,MNT,MOP,MRU,MTL,MUR,MVR,MWK,MXN,MYR,MZN,NAD,NGN,NIO,NOK,NPR,NZD,OMR,PAB,PEN,PGK,PHP,PKR,PLN,PYG,QAR,RON,RSD,RUB,RWF,SAR,SBD,SCR,SDG,SEK,SGD,SHP,SLL,SOS,SRD,SVC,SYP,SZL,THB,TJS,TMT,TND,TOP,TRY,TTD,TWD,TZS,UAH,UGX,USD,UYU,UZS,VND,XAF,XCD,XOF,XPF,YER,ZAR,ZMW';
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://live-metal-prices.p.rapidapi.com/v1/latest/{$to}/{$from}",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'GET',
            CURLOPT_HTTPHEADER => ['X-RapidAPI-Host: live-metal-prices.p.rapidapi.com', 'X-RapidAPI-Key: d808683ce3mshc0b04186ba5e0f1p1d2e0fjsnc70fc9f2201c'],
        ]);

        $response = curl_exec($curl);
        // $err = curl_error($curl);

        curl_close($curl);

        return $response;
    }







}
