<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class Archive extends Model
{
    protected $table = 'bp_archive';

    protected $primaryKey = 'a_id';
    
    protected $dates = ['created_at'];

    
    
    public static function getArchivePrices($bankId, $currencyId, $type = 'buy', $timePeriod = 30, $timeType = 'days')
    {
        switch ($timeType) {
            case 'days':
                $numberOfDays = $timePeriod;
                break;
            case 'months':
                $numberOfDays = $timePeriod; // تمثل 6 أشهر
                break;
            case 'years':
                $numberOfDays = ($timePeriod == 'all') ? 365 * 10 : $timePeriod; // تمثل سنتين
                break;
            default:
                $numberOfDays = $timePeriod;
        }
    
        $daysAgo = Carbon::today()->subDays($numberOfDays);
    
        $prices = self::select('created_at', 'a_price')->where('a_bank_id', $bankId)
            ->where('a_curn_id', $currencyId)
            ->where('a_option', $type)
            ->whereDate('created_at', '>=', $daysAgo)
            ->orderBy('created_at', 'desc')
            ->get()
            ->groupBy(function($date) use ($timeType, $timePeriod) {
                
                switch ($timeType) {
                    case 'days':
                        if ($timePeriod == 1)
                            return Carbon::parse($date->created_at)->format('Y-m-d H:m:s');
                        else
                            return Carbon::parse($date->created_at)->format('Y-m-d');
                        break;
                    case 'months':
                        return Carbon::parse($date->created_at)->format('Y-m-d');
                        break;
                    case 'years':
                        return Carbon::parse($date->created_at)->format('Y-m-d');
                        break;
                    default:
                        return Carbon::parse($date->created_at)->format('Y-m-d');
                }
            })->toArray();
    
        $dates = [];
        $pricesList = [];
    
        foreach ($prices as $date => $price) {
            $dates[] = $date;
            $lastPriceOfMonth = $price[0]['a_price'];
            $pricesList[] = $lastPriceOfMonth;
    
        }
    
        return ['dates' => array_reverse($dates), 'prices' => array_reverse($pricesList)];
    }
}
