<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Input as Input;


use App\Models\CurrenciesPrices;
use App\Models\Currencies;
use App\Models\Archive;
use Carbon\Carbon;
use Illuminate\Support\Facades\Cache;


class Query extends Model
{

  protected $guarded = array();
  public $timestamps = false;

  // get rates of this Bank
  public static function getCurrRatesByBank($Bank_slug)
  {
    $bank = Banks::select(['bank_id', 'bank_slug','bank_name_ar', 'bank_name_en', 'bank_image', 'is_lost', 'bank_last_update', 'updated_at', 'bank_url'])->where('active', 1)->where('bank_slug', $Bank_slug)->first();
    if ( $bank === null )
      return null;

    $bank->rates  = CurrenciesPrices::selectRaw('bp_bank_price.*')
                                                  ->with('currency:cur_code,cur_id,cur_flag,cur_name_ar,cur_name_en,cur_banks_support')
                                    ->where('bankp_bank_id', $bank->bank_id)
                                    ->get();
    return $bank;
  }
  // end of rates

 
  // get rates of this currency
  public static function getCurrRatesWithBanks($currency)
  {
    $cRates = Currencies::select(['cur_code', 'cur_id', 'cur_flag', 'cur_name_ar', 'cur_name_en', 'cur_banks_support'])->where('cur_code', strtoupper($currency))->first();
    if ( $cRates === null )
      return null;

    $cRates->rates  = CurrenciesPrices::selectRaw('bankp_bank_id,bankp_cur_id,bankp_sell_banknote,bankp_buy_banknote,bankp_status_buy,
    bankp_status_sell,
    bankp_percent_buy ,
    bankp_percent_sell,
    buy_change_amount,
    sell_change_amount,
    buy_change_percent,
    sell_change_percent,
    bankp_update,
    bp_banks.updated_at as updated_at,
    bank_slug,
    bank_name_ar,
    bank_name_en,
    bank_image')
                                                  ->join('bp_banks', 'bankp_bank_id', '=', 'bp_banks.bank_id')
                                                  ->where('bp_banks.active', 1)
                                                  ->where('bankp_cur_id', $cRates->cur_id)
                                                  ->orderBy('bankp_buy_banknote', 'desc')
                                                  // ->orderBy('is_lost', 'asc')
                                                  ->get();
    return $cRates;
  }
  // end of rates
  

    public static function getArchive($bankID,$currency_id, $type, $limit = 10)
    {
        $data = Archive::select('a_price')->where('a_curn_id', $currency_id)
                    ->where('a_bank_id', $bankID)
                    ->where('a_option', $type)->limit($limit)->orderBy('a_id', 'desc')->get();

        $newData = $data->map(function ($data){
          return round($data['a_price'], 5);
        })->toArray();

        $newData = array_reverse($newData);
        $newData = (implode(', ', $newData));


        return $newData;
    }

  // get best rate in this currency of bank
  public static function get_best_prices($currenies = [], $limit_banks = 1, $withArchive = true)
  {
    $cRates  = [];
    $twoDaysAgo = \Carbon\Carbon::now()->subDays(4);

    foreach ($currenies as $value)
    {
      //select(['cur_name_ar','cur_name_en','cur_flag','cur_code','cur_last_update'])->
      $cRates[$value] = Currencies::select(['cur_code', 'cur_id', 'cur_flag', 'cur_name_ar', 'cur_name_en', 'cur_banks_support'])->where('cur_code', $value)->first();
      $cRates[$value]['buy']  = CurrenciesPrices::select('*')
                                                      ->whereHas('bank', function ($query) {
                                                        $query->where('active','1')->where('is_lost', 0);
                                                      })
                                                    ->where('bankp_cur_id', $cRates[$value]->cur_id)
                                                    ->where('bankp_buy_banknote', '!=', 0)
                                                    ->where('updated_at', '>=', $twoDaysAgo)
                                                    // ->orderBy('bp_bank_price.updated_at', 'asc')
                                                    ->orderBy('bankp_buy_banknote', 'desc')
                                                    ->limit($limit_banks)
                                                    ->with('bank')
                                                    ->get();
      if ($withArchive)
        $cRates[$value]['buy'][0]['archives'] = self::getArchive($cRates[$value]['buy'][0]->bankp_bank_id, $cRates[$value]->cur_id, 'buy', 10);

      $cRates[$value]['sell']  = CurrenciesPrices::select('*')
      ->whereHas('bank', function ($query) {
        $query->where('active','1')->where('is_lost', 0);
    })
                                                    ->where('bankp_cur_id', $cRates[$value]->cur_id)
                                                    ->where('bankp_sell_banknote', '!=', 0)
                                                    ->where('bankp_sell_banknote', '>', $cRates[$value]['buy'][0]['bankp_buy_banknote'])
                                                    // ->whereRaw('DAY(bp_bank_price.updated_at) = DAY(CURRENT_DATE)')
                                                    ->where('updated_at', '>=', $twoDaysAgo)
                                                    ->orderBy('bankp_sell_banknote', 'asc')
                                                    ->orderBy('bp_bank_price.updated_at', 'desc')
                                                    ->limit($limit_banks)
                                                    ->with('bank')
                                                    ->get();
        //$cRates[$value]['sell'][0]['archives'] = self::getArchive($cRates[$value]['sell'][0]->bankp_bank_id, $cRates[$value]->cur_id, 'sell', 10);

    }

    return $cRates;
  }// end of get_best_prices from banks

  public static function banksSupportthisCurrency($currency_id)
  {
    $baks  = CurrenciesPrices::select('*')
                                                  ->join('bp_banks', 'bankp_bank_id', '=', 'bp_banks.bank_id')
                                                  ->where('bp_banks.active', 1)
                                                  ->where('bankp_cur_id', $currency_id)
                                                  ->where('bankp_buy_banknote', '!=', 0)
                                                  ->where('bankp_sell_banknote', '!=', 0)
                                                  ->get();
      return $baks;
  }// end of get banks support  this currency

  //
  public static function calculatorBanks($bank_id, $currency_id, $amount)
  {
      $amountRates = [];

      // get bank info & get currncy to in this bank
      $bankData  = CurrenciesPrices::select('*')
                  ->join('bp_banks', 'bankp_bank_id', '=', 'bp_banks.bank_id')
                  ->where('bp_banks.active', 1)
                  ->where('bp_banks.bank_id', $bank_id)
                  ->where('bankp_cur_id', $currency_id)
                  ->where('bankp_buy_banknote', '!=', 0)
                  ->where('bankp_sell_banknote', '!=', 0)
                  ->first();

       return [
         'amount'        => $amount,
         'currency_data' => Currencies::where('cur_id', $currency_id)->first(),
         'bank_data'     => $bankData,
          // 'another_banks' => self::calculatorAllBanks($in_bank, $from_currency, $quantity)
        ];
  }// end of get banks support  this currency
/*
  public static function calculatorAllBanks($notThis, $bank_id, $currency_id, $amount)
  {
      $this->db->select('bankp_sell_banknote, bankp_buy_banknote, banks.*');
      $this->db->from('bank_price');
      $this->db->join('banks', 'banks.bank_id = bank_price.bankp_bank_id', 'inner');
      $this->db->where('bankp_bank_id != ', $not_this);
      $this->db->where('bankp_cur_id', $currency);
      $this->db->where('active', 1);
      $this->db->where('bankp_sell_banknote != ' , 0);
      $this->db->where('bankp_buy_banknote != ' , 0);
      $this->db->group_by('bankp_bank_id');
      $dataRates = $this->db->get()->result_array();


      if ( count($dataRates) > 0 )
      {
        $return = array();
        $i = 0;
        foreach ($dataRates as $key)
        {
          $return[$i]['sell']     = $key['bankp_sell_banknote'] * $quantity; // سعر البيع للمواطنين
          $return[$i]['buy']      = $key['bankp_buy_banknote'] * $quantity; // سعر الشراء من المواطنين
          $return[$i]['bankData'] = $key;
          $i++;
        }
        return $return;
      }else {
        return null;
      }
  }// end of get banks support  this currency
*/

  // check rate in this bank by currency id
  public static function getBankRate($bank_id, $curr_id)
  {

    return CurrenciesPrices::select('*')
                                        ->join('bp_banks', 'bankp_bank_id', '=', 'bp_banks.bank_id')
                                        ->where('bp_banks.bank_id',$bank_id)
                                        ->where('bankp_cur_id', $curr_id)
                                        ->first();
  }
  // end of bake rates

  // check currency by code
  public static function getCurrencyByCode($currency_code)
  {

    return Currencies::select('*')->where('cur_code', $currency_code)->first();
  }
  // end of currency by code


  public static function getAllBankRates($limit = 0)
  {
    
    // return Cache::remember('getAllBankRatesEgyptCaddches', 6000000, function () use($limit) {
      $columns = [
        'bankp_sell_banknote',
        'bankp_buy_banknote',
        'bankp_id',
        'bankp_bank_id',
        'bankp_cur_id',
        'bankp_status_buy',
        'bankp_status_sell',
        'bankp_percent_buy',
        'bankp_percent_sell',
        'buy_change_amount',
        'sell_change_amount',
        'buy_change_percent',
        'sell_change_percent',
      ];
      $allCurrencies = Currencies::where('cur_banks_support', 1)
      ->when($limit > 0, function ($query) use ($limit) 
      {
        return $query->limit($limit);
      })->get();

      $egyptRates    = [];
      foreach ($allCurrencies as $key => $currency) {
        $egyptRates[$key]['currency'] = $currency;
        $egyptRates[$key]['rate'] = CurrenciesPrices::select($columns)->where('bankp_cur_id', $currency->cur_id)
        ->orderBy('bankp_buy_banknote', 'desc')
        ->first();
      }
      return $egyptRates;
    // });

    
  }


}
