<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class SilverArchive extends Model
{
    protected $table = 'bp_silver_archive';
    protected $primaryKey = 'archive_id';
    
    protected $dates = ['created_at'];

    
    

    public static function getArchivePrices($silverKarat, $timePeriod = 30, $timeType = 'days')
{
    switch ($timeType) {
        case 'days':
            $numberOfDays = $timePeriod;
            break;
        case 'months':
            $numberOfDays = $timePeriod; // تمثل 6 أشهر
            break;
        case 'years':
            $numberOfDays = ($timePeriod == 'all') ? 365 * 10 : $timePeriod; // تمثل سنتين
            break;
        default:
            $numberOfDays = $timePeriod;
    }

    $daysAgo = Carbon::today()->subDays($numberOfDays);

    $prices = self::where('archive_kind', $silverKarat->s_id)
        ->whereDate('created_at', '>=', $daysAgo)
        ->orderBy('created_at', 'desc')
        ->get()
        ->groupBy(function($date) use ($timeType, $timePeriod) {
            
            switch ($timeType) {
                case 'days':
                    if ($timePeriod == 1)
                        return Carbon::parse($date->created_at)->format('Y-m-d H:m:s');
                    else
                        return Carbon::parse($date->created_at)->format('Y-m-d');
                    break;
                case 'months':
                    return Carbon::parse($date->created_at)->format('Y-m-d');
                    break;
                case 'years':
                    return Carbon::parse($date->created_at)->format('Y-m');
                    break;
                default:
                    return Carbon::parse($date->created_at)->format('Y-m-d');
            }
        })->toArray();

    $dates = [];
    $pricesList = [];

    foreach ($prices as $date => $price) {
        $dates[] = $date;
        $lastPriceOfMonth = $price[0]['archive_price'];
        $pricesList[] = $lastPriceOfMonth;

    }

    return ['dates' => array_reverse($dates), 'prices' => array_reverse($pricesList)];
}

}
