<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.allBanksNew'),
    ]
]);
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$keywords = __('main.all_banks_keywords');
$keywordsText = implode(', ', $keywords);
// $dateAdded = '2022-07-14T00:00:00+0300';
// $dateUpdated = now()->format('Y-m-d\TH:i:s\Z');
$description =  __('main.all_banks_desc');
$title = __('main.allBanksNew');

?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description', $description)
@section('keywords', $keywordsText)
@section('article')
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
@endsection
@section('content')
@section('css')
    <style>
        .bank-card {
            transition: transform 0.3s, box-shadow 0.3s;
        }

        .bank-card:hover {
            transform: translateY(-10px);
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.1);
        }

        .bank-logo {
            width: 35px;
            height: 35px;
            object-fit: cover;
            border-radius: 50%;
        }

        .bank-info {
            flex-grow: 1;
        }

        .bank-update {
            color: #6c757d;
            font-size: 0.9rem;
            margin-bottom: 0;
            /* لإزالة المسافة السفلية */
        }

        .btn-small {
            padding: 0.25rem 0.5rem;
            font-size: 0.8rem;
        }

        .card-title {
            font-size: 1rem;
            margin-bottom: 0.5rem;
        }
    </style>
@endsection
<div class="container my-5 text-center text-md-start">
    <nav aria-label="breadcrumb mb-5 fs-6">
        <ol class="breadcrumb">
            <li class="breadcrumb-item">
                <a title="{{ __('main.goTo') }} {{ siteName() }}"
                    href="{{ url('/') }}" class="home">
                    <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                </a>
                <meta property="position" content="1">
            </li>
            <li class="breadcrumb-item active" aria-current="page">
                <span class="post post-post current-item">
                    {{ __('main.allBanksNew') }} </span>
            </li>
        </ol>
    </nav>
    <div class="my-5">
        <h1 class="text-center fw-bold fs-1">{{ __('main.allBanksNew') }}</h1>
        <span
            class="text-center opacity-75 bl-text-small d-block mb-5">{{ __('main.timeNow') }}{{ $dateNow }}</span>
    </div>


    <div class="row justify-content-between mt-5">
        <div class="col-12 col-lg-8 mb-5">
            <section id="ratesInBanks">
                <div id="table-container" class="table-wrapper">
                    <table class="table table-hover text-center"
                        style="box-shadow: 0 8px 16px 0 rgb(10 14 29 / 2%), 0 8px 64px 0 rgb(119 119 119 / 8%);border-radius: 10px; overflow: hidden;">
                        <thead>
                            <tr>
                                <th style="width: 25%;" class="text-center py-3">{{ __('main.currency') }}</th>
                                <th class="text-center py-3">{{ __('main.price_buy') }}</th>
                                <th class="text-center py-3">{{ __('main.price_sell') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($rates as $rate)
                                @if ($rate['rate']->bankp_buy_banknote == 0)
                                    @continue
                                @endif
                                <tr>
                                    <td class="text-start">
                                        <a class="fs-6" href="{{ currency_url($rate['currency']->toArray()) }}">
                                            {{-- <div class="info">
                      <img width="20" alt="{{$rate['currency']->name}}" class="bank-logo-small" data-src="/assets/img/loader.png" src="{{ $rate['currency']->smallflag }}" />
                      <span class="code">{{ $rate['currency']->cur_code }}EGP</span>
                    </div> --}}
                                            <img loading="lazy" width="15" alt="{{ $rate['currency']->name }}"
                                                class="bank-logo-small" data-src="/assets/img/loader.png"
                                                src="{{ $rate['currency']->smallflag }}" />
                                            <span class="currencyName">{{ $rate['currency']->name }}</span>
                                        </a>
                                    </td>
                                    <td class="text-center price {{ $rate['rate']->bankp_status_buy }}">
                                        <span
                                            class="bankRate">{{ priceFormat($rate['rate']->bankp_buy_banknote, 6) }}</span>
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        {{-- <div class="rate-change ltr fs-6 my-2">
                        <i class="fas fa-arrow-{{ $rate['rate']->bankp_status_buy }}"></i> {{ priceFormat($rate['rate']->bankp_percent_buy,5) }}%
                      </div> --}}
                                    </td>
                                    <td class="text-center price {{ $rate['rate']->bankp_status_sell }}">
                                        <span
                                            class="bankRate">{{ priceFormat($rate['rate']->bankp_sell_banknote, 6) }}</span>
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        {{-- <div class="rate-change ltr fs-6 my-2">
                        <i class="fas fa-arrow-{{ $rate['rate']->bankp_status_sell }}"></i> {{ priceFormat($rate['rate']->bankp_percent_sell,5) }}%
                      </div> --}}
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </section>
        </div>
        <div class="col-12 mb-2 col-lg-4">
            @include('partials.__calculator_egy_all_banks')
        </div>
    </div>
    
    <div class="row justify-content-between mt-5">
        <div class="col-12 mb-5">
            <h3 class="text-center fw-bold fs-1">{{ __('main.listOfBanks') }}</h3>

            <p class="text-muted mb-5 text-center opacity-75" style="    font-size: 13px;">
                {{ __('main.banks_desc') }}
            </p>
            <div class="row gy-4">
                @foreach (\App\Models\Banks::selectRaw('bank_id,bank_image,bank_last_update,bank_slug,bank_name_ar,bank_name_en')->where('active', 1)->orderByRaw('bank_sort = 0, bank_id asc')->get() as $bank)
                    <div class="col-12 col-sm-12 col-md-6 col-lg-4">
                        <a title="{{ __('main.bank_title', ['bank_name' => $bank->name]) }}"
                            href="{{ route('bank_price', ['slug' => $bank->bank_slug]) }}">
                            <div
                                class="card bank-card shadow-sm h-100 @if ($bank->is_central == 1) bg-warning-subtle @endif">
                                <div class="card-body d-flex align-items-center">
                                    <img loading="lazy" src="/uploads/35x35/{{ $bank['bank_image'] }}" alt="{{ $bank->name }}"
                                        class="bank-logo me-3">
                                    <div
                                        class="bank-info gap-2 d-flex align-items-start flex-column @if ($bank->is_central == 1) text-warning-emphasis @endif">
                                        <h5 class="card-title mb-1 text-truncate"style="font-size: 1rem; color: #333;">
                                            {{ $bank->name }}</h5>
                                        <div class="d-flex w-100 justify-content-between">
                                            <p class="card-text bank-update mb-1">{{ __('main.ago') }}
                                                {{ timeago($bank->bank_last_update) }}</p>
                                            <span class="btn btn-primary btn-small">
                                                <i class="fas m-0 fa-money-bill-wave"></i> {{ __('main.currenies_rates') }}
                                            </span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </a>
                    </div>
                @endforeach
            </div>
        </div>
    </div><!-- row justify-content-between -->
</div> <!-- container my-5 -->
@endsection
