<?php
use Carbon\Carbon;
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.allBanks'),
        'item' => LaravelLocalization::localizeUrl(route('banks'))
    ],
    [
        '@type' => 'ListItem',
        'position' => 3,
        'name' => bank_title($BPrices),
    ] 
]);



// $metalPrice = \App\Models\MetalPrices::where('metal_type', 'XAU')->first();
$dateNow = Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));

$lastUpdated = Carbon::parse($BPrices->updated_at);
$now = Carbon::now();
$differenceInHours = $now->diffInHours($lastUpdated);
$differenceInDays = $now->diffInDays($lastUpdated);


$keywords = __('main.bank_rates_keywords', ['bank' => $BPrices->name]);
$keywordsText = implode(', ', $keywords);
// $dateAdded = \Carbon\Carbon::parse($BPrices->created_at)->format('Y-m-d\TH:i:s\Z');
// $dateUpdated = \Carbon\Carbon::parse($BPrices->updated_at)->format('Y-m-d\TH:i:s\Z');
// $description =  __('main.gold_karat_desc', ['karat' => $BPrices->name]);
$title = __('main.bank_title', ['bank_name' => $BPrices->name]);

?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description')
    {{ __('main.bank_desc', [
        'bank_name' => $BPrices->name,
        'date' => timeago($BPrices->bank_last_update),
    ]) }}
@endsection
@section('img')
    {{ $BPrices->img_path }}
@endsection
@section('keywords', $keywordsText)
@section('article_tage')
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
@endsection

@section('content')
    <div class="container mt-4">
        <nav aria-label="breadcrumb mb-5 fs-6">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a title="{{ __('main.goTo') }} {{ siteName() }}"
                        href="{{ LaravelLocalization::localizeUrl('/') }}" class="home">
                        <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                    </a> 
                </li>
                <li class="breadcrumb-item">
                    <a href="{{ LaravelLocalization::localizeUrl(route('banks')) }}"><i class="fas fa-university"></i>
                        {{ __('main.allBanks') }}</a>
                </li>

                <li class="breadcrumb-item active" aria-current="page">
                    <span class="post post-post current-item">
                        <img width="20" src="{{ $BPrices->img_path }}" alt="{{ bank_title($BPrices) }}" />
                        {{ ucwords($BPrices->name) }}
                    </span>
                </li>
            </ol>
        </nav>


        <div class="my-3 text-center">
            <img width="100" alt="{{ $BPrices->name }}" class="mb-2"
                src="/uploads/420x420/{{ $BPrices->bank_image }}" />
            <h1 class="fw-bold my-3 fs-4">{{ bank_title($BPrices) }}</h1>
            <span class="opacity-75 my-3 bl-text-small d-block">{{ __('main.timeNow') }}{{ $dateNow }}</span>
            <a class="d-block my-3 bl-text-small " href="{{ $BPrices->bank_url }}" target="_blank"
                rel="nofollow noopener noreferrer">
                <i class="fas fa-external-link"></i> {{ __('main.bank_webite') }}
            </a>
        </div>
        <div class="row justify-content-between">
            <div class="col-12 col-lg-8 mb-5 px-0">
                <div class="mt-4 mb-2">
                    <p class="text-start mt-3 bl-text-small p-2">
                        <span class="start-head"></span>
                        {{ __('main.bank_head_table', ['name' => $BPrices->name, 'date' => $BPrices->updated_at->diffForHumans()]) }}
                    </p>
                    @if ($differenceInHours < 24)
                        <p class="text-start bl-text-xs rounded-3 bg-success text-light py-2 d-inline-block px-3">
                            <i class="fas fa-sync-alt fa-spin"></i> {{ __('main.refresh_data') }}
                        </p>
                    @endif
                    @if ($differenceInDays >= 1 && $differenceInDays <= 3)
                        <p class="text-start bl-text-xs rounded-3 bg-warning text-dark py-2 d-inline-block px-3">
                            <i class="fas fa-archive"></i> {{ __('main.old_data') }}
                        </p>
                    @endif
                    @if ($differenceInDays > 3)
                        <p class="text-start bl-text-xs rounded-3 bg-danger text-light py-2 d-inline-block px-3">
                            <i class="fas fa-exclamation-triangle"></i> {{ __('main.archive_data') }}
                        </p>
                    @endif
                </div>
                <div id="table-container" class="table-wrapper">
                    <table class="banklive-tablse table table-hover text-center">
                        <thead>
                            <tr>
                                <th class="text-center py-3">{{ __('main.currency') }}</th>
                                <th class="text-center py-3">{{ __('main.price_buy') }}</th>
                                <th class="text-center py-3">{{ __('main.price_sell') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($BPrices->rates as $rate)
                                @if ($rate['bankp_buy_banknote'] == 0)
                                    @continue
                                @endif
                                <tr>
                                    <td class="text-start">
                                        <a class="fs-6"
                                            href="{{ bankCurrencyUrl($BPrices->bank_slug, $rate->currency->cur_code) }}">
                                            <div class="info">
                                                <img width="20" alt="{{ $rate->currency->name }}"
                                                    class="bank-logo-small" data-src="/assets/img/loader.png"
                                                    src="{{ $rate->currency->smallflag }}" />
                                                <span class="code">{{ $rate->currency->cur_code }}EGP</span>
                                            </div>
                                            <span class="currencyName">{{ $rate->currency->name }}</span>
                                        </a>
                                    </td>
                                    <td class="text-center price <?= $rate['bankp_status_buy'] ?>">
                                        <span class="bankRate">{{ priceFormat($rate['bankp_buy_banknote'], 5) }}</span>
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        <div class="rate-change ltr fs-6 my-2">
                                            <i class="fas fa-arrow-{{ $rate['bankp_status_buy'] }}"></i>
                                            {{ priceFormat($rate['bankp_percent_buy'], 5) }}%
                                        </div>
                                    </td>
                                    <td class="text-center price <?= $rate['bankp_status_sell'] ?>">
                                        <span class="bankRate">{{ priceFormat($rate['bankp_sell_banknote'], 5) }}</span>
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        <div class="rate-change ltr fs-6 my-2">
                                            <i class="fas fa-arrow-{{ $rate['bankp_status_sell'] }}"></i>
                                            {{ priceFormat($rate['bankp_percent_sell'], 5) }}%
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>

            <div class="col-12 mb-5 col-lg-4">
                @include('partials.__calculator_egy_bank')
            </div>
        </div><!-- row justify-content-between mt-5 -->
    </div><!-- container mt-4 -->
@endsection