<?php 
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.allBanks'),
        'item' => LaravelLocalization::localizeUrl(route('banks'))
    ],
    [
        '@type' => 'ListItem',
        'position' => 3,
        'name' => $bank->name,
        'item' => bank_url($bank)
    ],
    [
        '@type' => 'ListItem',
        'position' => 4,
        'name' => $currency->name,
    ] 
]);
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));


$keywords = __('main.bank_currency_rate', ['currency' => $currency->name, 'bank' => $bank->name]);
$keywordsText = implode(', ', $keywords);
$dateAdded = \Carbon\Carbon::parse($bank->created_at)->format('Y-m-d\TH:i:s\Z');
$dateUpdated = \Carbon\Carbon::parse($bank->updated_at)->format('Y-m-d\TH:i:s\Z');
$description = __('main.infobankCurrencyRateShort', ['currency' => $currency->name, 'bank' => $bank->name, 'curFrom' => removeAlefLam($currency->name)]);
$title = __('main.bankCurrencyRate', ['currency' => $currency->name, 'bank' => $bank->name]);

?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description', $description)
@section('keywords', $keywordsText)
@section('article')
<meta property="article:published_time" content="{{ $dateAdded }}">
<meta property="article:modified_time" content="{{ $dateUpdated }}">
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
<script type="application/ld+json">
{
    "@context": "https://schema.org",
    "@type": "NewsArticle",
    "mainEntityOfPage": {
        "@type": "WebPage",
        "@id": "{{ bankCurrencyUrl($bank->bank_slug, $currency->cur_code) }}"
    },
    "headline": "{{ $title }}",
    "name": "{{ $title }}",
    "articleSection": "{{ $bank->name }}",
    "image": {
        "@type": "ImageObject",
        "url": "{{ url('assets/img/bank_live_logo.png') }}",
        "width": 851,
        "height": 315
    },
    "datePublished": "{{ $dateAdded }}",
    "dateModified": "{{ $dateUpdated }}",
    "inLanguage": "{{ __('main.lang_country') }}",
    "keywords": "{{ $keywordsText }}",
    "author": {
        "@type": "Person",
        "name": "BankLive-news"
    },
    "publisher": {
    "@type": "Organization",
    "name": "{{ siteName() }}",
    "logo": {
        "@type": "ImageObject",
        "width": 190,
        "height": 60,
        "url": "{{ url('assets/favicons/android-icon-192x192.png') }}"
    }
    },
    "description": "{{ $description }}"
}
</script>
@endsection
@section('css')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <div class="row justify-content-between mt-5">
            <div class="col-12">
                <nav aria-label="breadcrumb mb-5 fs-6">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.goTo') }} {{ siteName() }}"
                                href="{{ url('/') }}" class="home">
                                <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item">
                            <a href="{{ LaravelLocalization::localizeUrl(route('banks')) }}"><i
                                    class="fas fa-university"></i> {{ __('main.allBanks') }}</a>
                        </li>
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.bankRatesToday') }}"
                                href="{{ bank_url($bank) }}">
                                <span property="name">
                                    <img class="currency-flag rounded-5" width="15" src="{{ $bank->img_path }}"
                                        alt="{{ bank_title($bank) }}" /> {{ ucwords($bank->name) }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <span class="post post-post current-item">
                                <img src="{{ $currency->smallflag }}" class="currency-flag rounded-5" width="15"
                                    alt="{{ $currency->name }}">
                                {{ $currency->name }}
                            </span>
                            <meta property="position" content="4">
                        </li>
                    </ol>
                </nav>
            </div>
            <div class="col-12 col-lg-8 mb-3">
                <div class="my-2 text-start">
                    <img class="rounded-5 align-middle" src="{{ $currency->smallflag }}" width="25" height="25"
                        alt="{{ $currency->name }} flag">
                    <h1 class="h1-page d-inline mx-0 mb-1 fw-bold fs-4">
                        {{ __('main.bankCurrencyRate', ['currency' => $currency->name, 'bank' => $bank->name]) }}
                    </h1>
                    <p class="text-start bl-text-small mt-3 mb-3">
                        {{ __('main.infoBankCurrencyRate', ['currency' => $currency->name, 'bank' => $bank->name]) }}
                        {{ $dateNow }}
                    </p>
                </div>
                <section class="row" id="fast-price-info">
                    <!-- Best Buy Section -->
                    <div class="col-sm-6">
                        <div class="card  my-3">
                            <div class="card-body">
                                <div class="priceTypeFancyInfo">{{ __('main.price_buy') }}
                                    <div class="font-1 text-end font-lg-5 spinner-grow text-light spinner"></div>
                                </div>
                                <div class="d-flex gap-3 justify-content-center flex-row-reverse align-items-center">
                                    <div>
                                        <div class="{{ $currencyRateInBank->bankp_status_buy }} ltr">
                                            <i class="fas fa-arrow-{{ $currencyRateInBank->bankp_status_buy }}"></i>
                                            {{ priceFormat($currencyRateInBank['buy_change_amount'], 3) }}
                                            {{ priceFormat($currencyRateInBank['buy_change_percent'], 3) }}%
                                        </div>
                                    </div>
                                    <div class="text-center">
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        <span
                                            class="count_money fw-bold fs-1">{{ priceFormat($currencyRateInBank->bankp_buy_banknote, 5) }}</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Best Sell Section -->
                    <div class="col-sm-6">
                        <div class="card  my-3">
                            <div class="card-body">
                                <div class="priceTypeFancyInfo">{{ __('main.price_sell') }}
                                    <div class="font-1 text-end font-lg-5 spinner-grow text-light spinner"></div>
                                </div>
                                <div class="d-flex gap-3 justify-content-center flex-row-reverse align-items-center">
                                    <div class="text-center">
                                        <div class="{{ $currencyRateInBank->bankp_status_sell }} ltr">
                                            <i class="fas fa-arrow-{{ $currencyRateInBank->bankp_status_sell }}"></i>
                                            {{ priceFormat($currencyRateInBank['sell_change_amount'], 3) }}
                                            {{ priceFormat($currencyRateInBank['sell_change_percent'], 3) }}%
                                        </div>
                                    </div>
                                    <div class="text-center">
                                        <span class="small">{{ __('main.egCurr') }}</span>
                                        <span
                                            class="count_money fw-bold fs-1">{{ priceFormat($currencyRateInBank->bankp_sell_banknote, 5) }}</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <section id="morePrices">
                    <div class="row">
                        <div class=" col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span
                                        class="start-head bg-{{ statusBG($previousClosuresPrice->status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.lastClose') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($previousClosuresPrice->price, 5) }}</span>
                                    <span class="fs-6 ltr {{ $previousClosuresPrice->status }}">
                                        <i class="fas fa-arrow-{{ $previousClosuresPrice->status }}"></i>
                                        {{ priceFormat($previousClosuresPrice->change_percent, 5) }}%
                                        {{ priceFormat($previousClosuresPrice->change_amount, 5) }}
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class=" col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span class="start-head bg-{{ statusBG($generalRates->change_status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.priceGlobally') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($generalRates->current_price, 5) }}</span>
                                    <span class="fs-6 ltr {{ $generalRates->change_status }}">
                                        <i class="fas fa-arrow-{{ $generalRates->change_status }}"></i>
                                        {{ priceFormat($generalRates->change_percent, 5) }}%
                                        {{ priceFormat($generalRates->change_amount, 5) }}
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <div id="chartFilter" class="p-2 my-5">
                    <div class="py-2 d-flex flex-column gap-3">
                        <div class="d-flex align-items-center head">
                            <span class="start-head bg-danger top-0"></span>
                            <img class="rounded-5 ms-1" src="{{ $currency->smallflag }}" width="25" height="25"
                                alt="{{ $currency->name }} flag">
                            <span class="mx-2 fs-6 opacity-75">
                                {{ __('main.bank_currency_archive', ['currencyName' => $currency->name , 'bankName' => $bank->name]) }}
                            </span>
                        </div>
                        <form method="GET">
                            <div class="btn-group" role="group" aria-label="Duration selection">
                                <input type="hidden" name="days" id="days-input"
                                    value="{{ isset($filter) ? $filter : '7' }}">
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '7') active @endif"
                                    onclick="setDays(7)">{{ __('main.last7Days') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '30') active @endif"
                                    onclick="setDays(30)">{{ __('main.last30Days') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '90') active @endif"
                                    onclick="setDays(90)">{{ __('main.last3Months') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '180') active @endif"
                                    onclick="setDays(180)">{{ __('main.last6Months') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '365') active @endif"
                                    onclick="setDays(365)">{{ __('main.lastYear') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == 'all') active @endif"
                                    onclick="setDays('all')">{{ __('main.all') }}</button>
                            </div>
                        </form>
                    </div>
                    <div style="width: 100%;overflow: hidden;position: relative;">
                        <canvas id="goldchart-id" height="300"
                            style="display: block; box-sizing: border-box; height: 346px; width: 693px;"></canvas>
                    </div>
                </div>
                <div class="getMoreItems my-5">
                    <div class="mb-4">
                        <h2 class="text-start fs-5 mb-0">
                            <span class="start-head bg-danger"></span>
                            <img src="{{ $currency->smallflag }}" class="rounded-5" width="15" height="15">
                            {{ __('main.currency_in_banks', ['currrencyName' => $currency->name]) }}
                        </h2>
                    </div>
                    <div class="contai7ner-fluid">
                        <div class="swiper mySwiper goldListKarats">
                            <div class="swiper-wrapper">
                            @foreach ($morePrices as $morePrice)
                                    <div style="background: rgb(248 248 255 / 62%);"
                                        class="petrol swiper-slide co7l-3 border border-light-subtle rounded-4 p-3">
                                        <a href="{{bankCurrencyUrl($morePrice->bank_slug, $currency->cur_code)}}"
                                            class="text-decoration-none">
                                            <div
                                                class="align-items-center d-flex flex-row-reverse gap-2 justify-content-end">
                                                <h2 class="fs-6 fw-s">
                                                    {{ $morePrice->name }}
                                                </h2>
                                                <img class="rounded-5" width="25" height="25" src="{{ $morePrice->img_path }}">
                                            </div>
                                            <div
                                                class="flex-row-reverse align-items-baseline flex-row gap-3 justify-content-center d-flex ltr mt-3">
                                                <div class="fw-bold fs-3 color-main-price">{{ priceFormat($morePrice->currencyPrices->bankp_buy_banknote) }}
                                                    <span class="bl-text-xs">{{ __('main.egCurr') }}</span>
                                                </div>
                                                <span dir="ltr"
                                                    class="fw-normal ltr bl-text-sm {{ $morePrice->currencyPrices->bankp_status_buy }}">
                                                    <i class="fas fa-arrow-{{ $morePrice->currencyPrices->bankp_status_buy }}"></i>
                                                    {{ $morePrice->currencyPrices->bankp_percent_buy }}%</span>
                                            </div>
                                        </a>
                                    </div>
                                @endforeach
                                <div style="background: rgb(248 248 255 / 62%);"
                                        class="h-auto swiper-slide border border-light-subtle rounded-4 p-3">
                                        <a href="{{currency_url($currency->toArray())}}" class="text-decoration-none">
                                            <div class="align-items-center d-flex justify-content-center h-100 w-100">
                                                <span class="fs-6 fw-s">
                                                   {{ __('main.click_to_more') }}
                                                </span>
                                            </div>
                                        </a>
                                    </div>
                            </div>
                            <div class="swiper-button-next"></div>
                            <div class="swiper-button-prev"></div>
                        </div>
                    </div>
                </div>
            </div><!-- col-12 col-lg-8 mb-5 -->
            <div class="col-12 mb-2 col-lg-4">
                @include('partials.__calculator_egy_bank')
            </div>
            <div class="col-12 col-lg-8 mb-5">
                <div class="row">
                    <div class="col-12 col-md-6 my-2">
                        <div class="block table-converter">
                            <div class="block-header no-border">
                                <h4 class="fs-6">
                                    {{ __('main.from_to', ['from' => $currency->shortName, 'to' => __('main.short_egp')]) }}
                                </h4>
                            </div>
                            <div class="block-content">
                                <table class="rates-table table table-hover infoTable">
                                    <thead>
                                        <tr>
                                            <th class=" text-center"><img src="{{ $currency->smallflag }}"
                                                    width="15" height="15" alt="{{ $currency->name }} flag">
                                                {{ $currency->name }}</th>
                                            <th class=" text-center"><img src="/flags/1x1/eg.svg" width="15"
                                                    height="15" alt="{{ __('main.EGP') }} flag"> {{ __('main.EGP') }}
                                            </th>
                                        </tr>
                                    </thead>
                                    <tbody class="text-center">
                                        @foreach (getExpPrices() as $price)
                                            <tr>
                                                <td class="no-border">{{ number_format($price) }}
                                                    {{ removeAlefLam($currency->name) }}</td>
                                                <td class="no-border">
                                                    {{ priceFormat($price * $currency->rates->current_price, 6) }}
                                                    {{ __('main.EGP') }}</td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                    <div class="col-12 col-md-6 my-2">
                        <div class="block table-converter">
                            <div class="block-header no-border">
                                <h4 class="fs-6">
                                    {{ __('main.from_to', ['from' => __('main.short_egp'), 'to' => $currency->shortName]) }}
                                </h4>
                            </div>
                            <div class="block-content">
                                <table class="rates-table table table-hover infoTable">
                                    <thead>
                                        <tr>
                                            <th class=" text-center"><img src="/flags/1x1/eg.svg" width="15"
                                                    height="15" alt="{{ __('main.EGP') }} flag"> {{ __('main.EGP') }}
                                            </th>
                                            <th class=" text-center"><img src="{{ $currency->smallflag }}"
                                                    width="15" height="15" alt="{{ $currency->name }} flag">
                                                {{ $currency->name }}</th>
                                        </tr>
                                    </thead>
                                    <tbody class="text-center">
                                        @foreach (getExpPrices() as $price)
                                            <tr>
                                                <td class="no-border">{{ number_format($price) }} {{ __('main.EGP') }}
                                                </td>
                                                <td class="no-border">
                                                    {{ priceFormat($price / $currency->rates->current_price, 3) }}
                                                    {{ removeAlefLam($currency->cur_code) }}</td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-12 col-lg-4 mb-5">
                @include('components.egypt_central_bank')
            </div>
        </div><!-- row -->
    </div><!-- container -->
@endsection
@section('js')
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script>
        var swiper = new Swiper(".goldListKarats", {
            slidesPerView: 4,
            spaceBetween: 10,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            navigation: {
                nextEl: ".swiper-button-next",
                prevEl: ".swiper-button-prev",
            },
            freeMode: true,
            breakpoints: {
                900: {
                    slidesPerView: 3,
                },
                768: {
                    slidesPerView: 2,
                },
                576: {
                    slidesPerView: 1,
                },
                350: {
                    slidesPerView: 1,
                },
                0: {
                    slidesPerView: 1,
                },
            }
        });
        $(document).ready(function() {
            slimCalculator();
        });
        $('#amount').on('change', function() {
            return slimCalculator();
        });

        function slimCalculator() {
            var amount = $('#amount').val();
            var currencyRate = $('#amount').data('currency-rates');
            var fromCurrency = $('.from-currency').find(":selected").val();
            var toCurrency = $('.to-currency').find(":selected").val();

            var textFromCurrency = $('.from-currency').find(":selected").text();
            var textToCurrency = $('.to-currency').find(":selected").text();

            if (toCurrency == 'EGP') {
                result = amount * currencyRate;
            } else {
                result = amount / currencyRate;
            }

            result = result.toLocaleString('en-US');
            $('#cal-result').html(result + ' ' + textToCurrency);
        }


        $('.select-swap').click(function() {
            var $to = $('.to-currency option');
            var $from = $('.from-currency option');
            /* Store the selected values */
            var to = $('.to-currency option:checked').text();
            var from = $('.from-currency option:checked').text();
            $('.from_cur_text').html(to);
            $('.to_cur_text').html(from);
            /* Swap the option lists */
            $('.from-currency').append($to);
            $('.to-currency').append($from);
            /* Re-set the selected values */
            $('.from-currency option:contains(' + $to + ')').prop('selected', true);
            $('.to-currency option:contains(' + $from + ')').prop('selected', true);

            return slimCalculator();
        });


        document.addEventListener("DOMContentLoaded", () => {
            setTimeout(function() {


                const plugin = {
                    id: 'verticalLiner',
                    afterInit: (chart, args, opts) => {
                        chart.verticalLiner = {}
                    },
                    afterEvent: (chart, args, options) => {
                        const {
                            inChartArea
                        } = args
                        chart.verticalLiner = {
                            draw: inChartArea
                        }
                    },
                    beforeTooltipDraw: (chart, args, options) => {
                        const {
                            draw
                        } = chart.verticalLiner
                        if (!draw) return

                        const {
                            ctx
                        } = chart
                        const {
                            top,
                            bottom
                        } = chart.chartArea
                        const {
                            tooltip
                        } = args
                        const x = tooltip?.caretX
                        if (!x) return

                        ctx.save()
                        ctx.lineWidth = 1;
                        ctx.strokeStyle = '#87b6d9';

                        ctx.beginPath()
                        ctx.moveTo(x, top)
                        ctx.lineTo(x, bottom)
                        ctx.stroke()
                        ctx.restore()
                    }
                }


                let myChart = new Chart(document.getElementById('goldchart-id').getContext('2d'), {
                    type: 'line',
                    data: {
                        labels: [
                            @foreach ($getArchivePrices['dates'] as $date)
                                "{{ $date }}",
                            @endforeach
                        ],
                        datasets: [{
                            label: "{{ __('main.price_buy') }}",
                            data: [
                                @foreach ($getArchivePrices['prices'] as $price)
                                    "{{ $price }}",
                                @endforeach
                            ],
                            backgroundColor: "#e5eff5",
                            borderColor: '#87b6d9',
                            // pointStyle: 'rect',
                            // lineTension: '.15',
                            tension: 0.1,
                            fill: true,
                            // pointStyle: "circle",
                            // pointBorderColor: "#202839",
                            // pointBackgroundColor: "#fff",
                            // pointRadius: 1,
                            // borderWidth: 2.5,


                        }]
                    },
                    plugins: [plugin],

                    options: {
                        responsive: true,
                        interaction: {
                            intersect: false,
                            mode: 'index',
                            axis: 'x'
                        },
                        plugins: {
                            legend: {
                                display: false,
                                labels: {
                                    font: {
                                        size: 14,
                                        family: "dubai"
                                    }
                                }
                            }
                        },
                        scales: {
                            x: {
                                ticks: {
                                    autoSkip: true,
                                    maxTicksLimit: 3
                                },
                                // display:false,
                                beginAtZero: false,
                                grid: {
                                    display: false
                                }
                            },
                            y: {
                                grid: {
                                    display: true,
                                    color: "rgb(3,169,244,0.05)"
                                }
                            },

                        },
                        hover: {
                            mode: 'index'
                        },
                        legend: {
                            labels: {

                                fontFamily: 'dubai',
                                defaultFontFamily: 'dubai',
                            }
                        },
                        elements: {
                            line: {
                                tension: 1
                            }
                        }
                    }
                });
            }, 500);
        });
    </script>
@endsection
