<?php
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$randomCurrencies = \App\Models\Currencies::whereHas('rates', function ($query) {
    return $query->where('to_cur_id', 50)->whereNotNull('current_price');
})
    ->with('rates')
    ->where('is_active', 1)
    ->where('is_lost', 0)
    ->where('cur_banks_support', 0)
    ->limit(20)
    ->inRandomOrder()
    ->get();
$updated_at = \Carbon\Carbon::parse($currency->updated_at)->format('Y-m-d H:m:i');

\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/'),
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.allCurrenciesNew'),
        'item' => \LaravelLocalization::localizeUrl(route('currencies')),
    ],
    [
        '@type' => 'ListItem',
        'position' => 3,
        'name' => $currency->name . ' / ' . __('main.egyPound'),
    ],
]);


$keywords = __('main.cur_keywords_page', ['currency_code' => $currency->cur_code, 'currency' => $currency->name]);
$keywordsText = implode(', ', $keywords);
$dateAdded = \Carbon\Carbon::parse($currency->created_at)->format('Y-m-d\TH:i:s\Z');
$dateUpdated = \Carbon\Carbon::parse($currency->updated_at)->format('Y-m-d\TH:i:s\Z');
$description =  __('main.newCurrencyPageDesc', ['cur_from_name' => $currency->name, 'cur_from_code' => $currency->cur_code, 'curFrom' => removeAlefLam($currency->name)]);
$title = __('main.newCurrencyPageTitle', ['cur_from_name' => $currency->name, 'cur_from_code' => $currency->cur_code]);
?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description', $description)
@section('keywords', $keywordsText)
@section('article_tage')
<meta property="article:published_time" content="{{ $dateAdded }}">
<meta property="article:modified_time" content="{{ $dateUpdated }}">
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
@endsection
@section('css')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/css/bootstrap-select.min.css"
        rel="stylesheet">
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <div class="row justify-content-between mt-5">
            <div class="col-12">
                <nav aria-label="breadcrumb mb-5 fs-6">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"">
                            <a property="item" typeof="WebPage" title="{{ __('main.goTo') }} {{ siteName() }}"
                                href="{{ url('/') }}" class="home">
                                <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.allCurrenciesNew') }}" href="{{ route('currencies') }}">
                                <span>{{ __('main.allCurrenciesNew') }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <span class="post post-post current-item">
                                {{ $currency->name }} / {{ __('main.egyPound') }}</span>
                        </li>
                    </ol>
                </nav>
            </div>
            <div class="col-12 col-lg-8 mb-3">
                <div class="my-2 text-start">
                    <img class="rounded-5" style="vertical-align: middle;" src="{{ $currency->smallflag }}" width="25"
                        height="25" alt="{{ $currency->name }} flag">
                    <h1 class="d-inline h1-page mx-0 mb-1 fw-bold fs-4">
                        {{ __('main.newCurrencyPageTitle', ['cur_from_name' => $currency->name, 'cur_from_code' => $currency->cur_code]) }}
                    </h1>
                    <p class="text-start bl-text-small mt-3 mb-3">
                        {{ __('main.newCurrencyPageDesc', ['cur_from_name' => $currency->name, 'cur_from_code' => $currency->cur_code, 'curFrom' => removeAlefLam($currency->name)]) }}
                        {{ $dateNow }}
                    </p>
                </div>
                <div id="sectionMainPrice">
                    <section class="row" id="fast-price-info">
                        <div class="col-sm-12">
                            <div class="card my-3 petrol">
                                <div class="card-body">
                                    <div class="priceTypeFancyInfo">{{ __('main.last_move') }} {{ $updated_at }}
                                        <div class="font-1 text-end font-lg-5 spinner-grow text-light spinner"></div>
                                    </div>
                                    <div class="d-flex justify-content-center align-items-baseline gap-3" id="priceData">
                                        <span
                                            class="color-main-price d-flex align-items-baseline ltr mainPagePrice fw-bold">
                                            {{ $currency->rates->current_price }}
                                            <span class="bl-text-small">{{ __('main.egCurr') }}</span>
                                        </span>
                                        <div class="small ltr fs-5 {{ $currency->rates->change_status }}">
                                            <i class="fas fa-arrow-{{ $currency->rates->change_status }}"></i>
                                            {{ $currency->rates->change_percent }}%
                                            {{ $currency->rates->change_amount }}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <section id="morePrices">
                    <div class="row">
                        <div class="col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span
                                        class="start-head bg-{{ statusBG($currency->rates->change_status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.yesterdayClose') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($currency->rates->previous_price, 5) }}</span>
                                    <span class="fs-6 ltr {{ $currency->rates->change_status }}">
                                        <i class="fas fa-arrow-{{ $currency->rates->change_status }}"></i>
                                        {{ priceFormat($currency->rates->change_percent, 5) }}%
                                        {{ priceFormat($currency->rates->change_amount, 5) }}
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>

                <div class="py-1 my-3 bl-text-xs  text-start fw-normal opacity-75 text-danger">
                    <i class="fas fa-info-circle"></i>
                    {{ __('main.gcurrenyNotSupport', ['cur_from_name' => $currency->name]) }}
                </div>
                <div class="getMoreItems my-4" style="border-radius: 5px;">
                    <div class="head pb-4">
                        <h5 class="text-start fs-5 mb-0">
                            <span class="start-head bg-danger"></span> {{ __('main.moreCurreniesEgp') }}
                        </h5>
                    </div>
                    <div class="contai7ner-fluid">
                        <div class="swiper mySwiper goldListKarats">
                            <div class="swiper-wrapper">
                                @foreach ($randomCurrencies as $randomcurrency)
                                    <div style="background: rgb(248 248 255 / 62%);"
                                        class="petrol swiper-slide co7l-3 border border-light-subtle rounded-4 p-3">
                                        <a href="{{ route('currency', ['c_from' => $randomcurrency->cur_code, 'c_to' => 'EGP']) }}"
                                            class="text-decoration-none">
                                            <div
                                                class="align-items-center d-flex flex-row-reverse gap-2 justify-content-end">
                                                <h2 class="fs-6 fw-s">
                                                    {{ $randomcurrency->name }}
                                                </h2>
                                                <img class="rounded-5"
                                                    style="border-radius: 50%; width: 25px; height: 25px;"
                                                    src="{{ $randomcurrency->smallflag }}" width="25" height="25"
                                                    alt="{{ $randomcurrency->name }} flag">
                                            </div>
                                            <div
                                                class="flex-row-reverse align-items-baseline flex-row gap-3 justify-content-center d-flex ltr mt-3">
                                                <div class="fw-bold fs-3 color-main-price">
                                                    {{ $randomcurrency->rates->current_price }}<span
                                                        class="bl-text-xs">{{ __('main.egCurr') }}</span></div>
                                                <span dir="ltr"
                                                    class="fw-normal ltr bl-text-sm {{ $randomcurrency->rates->change_status }}">
                                                    <i
                                                        class="fas fa-arrow-{{ $randomcurrency->rates->change_status }}"></i>
                                                    {{ $randomcurrency->rates->change_percent }}%</span>
                                            </div>
                                        </a>
                                    </div>
                                @endforeach
                            </div>
                            <div class="swiper-button-next"></div>
                            <div class="swiper-button-prev"></div>
                        </div>
                    </div>
                </div>
            </div><!-- col-12 col-lg-8 mb-5 -->
            <div class="col-12 mb-2 col-lg-4">
                @include('partials.__calculator_egy_market_general', [
                    'baseCurrency' => $currency->cur_code,
                ])
            </div>
            <div class="col-12 col-lg-8 mb-5">
                <div class="row">
                    <div class="col-12 col-md-6 my-3">
                        <div class="block table-converter">
                            <div class="block-header no-border">
                                <h4 class="fs-6">
                                    {{ __('main.from_to', ['from' => $currency->shortName, 'to' => __('main.short_egp')]) }}
                                </h4>
                            </div>
                            <div class="block-content">
                                <table class="rates-table table table-hover infoTable">
                                    <thead>
                                        <tr>
                                            <th class=" text-center"><img src="{{ $currency->smallflag }}"
                                                    width="15" height="15" alt="{{ $currency->name }} flag">
                                                {{ $currency->name }}</th>
                                            <th class=" text-center"><img src="/flags/1x1/eg.svg" width="15"
                                                    height="15" alt="{{ __('main.EGP') }} flag"> {{ __('main.EGP') }}
                                            </th>
                                        </tr>
                                    </thead>
                                    <tbody class="text-center">
                                        @foreach (getExpPrices() as $price)
                                            <tr>
                                                <td class="no-border">{{ number_format($price) }}
                                                    {{ removeAlefLam($currency->name) }}</td>
                                                <td class="no-border">
                                                    {{ priceFormat($price * $currency->rates->current_price, 6) }}
                                                    {{ __('main.EGP') }}</td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                    <div class="col-12 col-md-6 my-3">
                        <div class="block table-converter">
                            <div class="block-header no-border">
                                <h4 class="fs-6">
                                    {{ __('main.from_to', ['from' => __('main.short_egp'), 'to' => $currency->shortName]) }}
                                </h4>
                            </div>
                            <div class="block-content">
                                <table class="rates-table table table-hover infoTable">
                                    <thead>
                                        <tr>
                                            <th class=" text-center"><img src="/flags/1x1/eg.svg" width="15"
                                                    height="15" alt="{{ __('main.EGP') }} flag"> {{ __('main.EGP') }}
                                            </th>
                                            <th class=" text-center"><img src="{{ $currency->smallflag }}"
                                                    width="15" height="15" alt="{{ $currency->name }} flag">
                                                {{ $currency->name }}</th>
                                        </tr>
                                    </thead>
                                    <tbody class="text-center">
                                        @foreach (getExpPrices() as $price)
                                            <tr>
                                                <td class="no-border">{{ number_format($price) }} {{ __('main.EGP') }}
                                                </td>
                                                <td class="no-border">
                                                    {{ priceFormat($price / $currency->rates->current_price, 3) }}
                                                    {{ removeAlefLam($currency->cur_code) }}</td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-12 col-lg-4 mb-5">
                @include('components.egypt_central_bank')
            </div>
        </div><!-- row -->
    </div><!-- container -->
@endsection

@section('js')
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/js/bootstrap-select.min.js"></script>
    <script>
        var swiper = new Swiper(".goldListKarats", {
            slidesPerView: 4,
            spaceBetween: 10,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            navigation: {
                nextEl: ".swiper-button-next",
                prevEl: ".swiper-button-prev",
            },
            freeMode: true,
            breakpoints: {
                900: {
                    slidesPerView: 3,
                },
                768: {
                    slidesPerView: 2,
                },
                576: {
                    slidesPerView: 1,
                },
                350: {
                    slidesPerView: 1,
                },
                0: {
                    slidesPerView: 1,
                },
            }
        });
    </script>
@endsection
