<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.gold_title'),
    ]
]);
$metalPrice = \App\Models\MetalPrices::where('metal_type', 'XAU')->first();
$time_format = __('main.time_format');
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$keywords = __('main.gold_main_keywords');
$keywordsText = implode(', ', $keywords);
$dateAdded = \Carbon\Carbon::parse($gold_prices->first()->created_at)->format('Y-m-d\TH:i:s\Z');
$dateUpdated = \Carbon\Carbon::parse($gold_prices->first()->updated_at)->format('Y-m-d\TH:i:s\Z');
?>
@extends('app')
@section('title', __('main.gold_title'))
@section('type', 'article')
@section('description', __('main.gold_desc'))
@section('keywords', $keywordsText)
@section('article_tage')
<meta property="article:published_time" content="{{ $dateAdded }}">
<meta property="article:modified_time" content="{{ $dateUpdated }}">
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <nav aria-label="breadcrumb mb-5 fs-6">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a title="{{ __('main.goTo') }} {{ siteName() }}"
                        href="{{ url('/') }}" class="home">
                        <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                    </a>
                </li>
                <li class="breadcrumb-item active" aria-current="page">
                    <span class="post post-post current-item">
                        {{ __('main.gold_title') }} </span>
                </li>
            </ol>
        </nav>
        <div class="my-5" id="mainTitle">
            <h1 class="text-center fw-bold fs-1">{{ __('main.gold_title') }}</h1>
            <span class="text-center d-block mb-5">{{ __('main.timeNow') }}{{ $dateNow }}</span>
        </div>
        <div class="row justify-content-between mt-5">
            <div class="col-12 col-lg-8 mb-5">
                <table class="table table-hover text-center banklive-table">
                    <thead>
                        <tr>
                            <th class="text-start">{{ __('main.unit') }}</th>
                            <th class="text-center py-3">{{ __('main.price_buy') }}</th>
                            <th class="text-center py-3">{{ __('main.price_sell') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td class="text-start">
                                <div class="info">
                                    <span class="code">XAUUSD</span>
                                </div>
                                {{ __('main.us_gold_onz_price') }}
                            </td>
                            <td class="text-center">
                                <span class="rate">
                                    ${{ priceFormat($metalPrice->price) }}
                                </span>
                                <div class="rate-change {{ $metalPrice->change_status }} ltr fs-6 my-2">
                                    <i class="fas fa-arrow-{{ $metalPrice->change_status }}"></i>
                                    {{ priceFormat($metalPrice->change_percent, 5) }}%
                                </div>
                            </td>
                            <td class="text-center">
                                <span class="rate">
                                    ${{ priceFormat($metalPrice->price + 1) }}
                                </span>
                                <div class="rate-change {{ $metalPrice->change_status }} ltr fs-6 my-2">
                                    <i class="fas fa-arrow-{{ $metalPrice->change_status }}"></i>
                                    {{ priceFormat($metalPrice->change_percent, 5) }}%
                                </div>
                            </td>
                        </tr>
                        @foreach ($gold_prices as $gold)
                            <tr>
                                <td class="text-start">
                                    <a href="{{ route('gold_karat', ['karat' => $gold->slug]) }}"
                                        title="{{ $gold->name }}">
                                        <div class="info">
                                            <span class="code">XAUEGP</span>
                                        </div>
                                        {{ $gold->name }}
                                    </a>
                                </td>
                                <td class="text-center">
                                    <span class="rate">
                                        @if ($gold->rate->buy_price == 0)
                                            {{ priceFormat($gold->rate->p_price) }}
                                        @else
                                            {{ priceFormat($gold->rate->buy_price) }}
                                        @endif
                                    </span>
                                    {{-- <span class="small">ج.م</span> --}}
                                    <div class="rate-change {{ $gold->rate->buy_status }} ltr fs-6 my-2">
                                        <i class="fas fa-arrow-{{ $gold->rate->buy_status }}"></i>
                                        {{ priceFormat($gold->rate->buy_change_percent, 2) }}%
                                    </div>
                                </td>
                                <td class="text-center price">
                                    <span class="rate">
                                        {{ priceFormat($gold->rate->p_price) }}
                                    </span>
                                    {{-- <span class="small">ج.م</span> --}}
                                    <div class="rate-change {{ $gold->rate->p_status }} ltr fs-6 my-2">
                                        <i class="fas fa-arrow-{{ $gold->rate->p_status }}"></i>
                                        {{ priceFormat($gold->rate->p_status_percentage, 2) }}%
                                    </div>
                                </td>

                                {{-- <td class="border-0 fs-6 text-center ltr  fw-bold price_{{ $gold->rate->p_status }}">
                    <i class="fas fa-caret-{{ $gold->rate->p_status }}"></i>
                    <span>{{ number_format(priceFormat($gold->rate->change_amount, 4), 2) }}</span> (<span>{{ priceFormat($gold->rate->p_status_percentage, 2) }}%</span>)
                      </td> --}}
                            </tr>
                        @endforeach
                    </tbody>
                </table>
                <p class="text-muted text-center mt-4">
                    {{ __('main.gold_desc') }}
                </p>
                <section class="market-rate">
                  <div class="mb-4">
                    <h2 class="text-start font-3 mb-0">
                        <span class="start-head" style="background: #ff9800;"></span> {{ __('main.goldGeneral') }}
                    </h2>
                    <h3 class="text-start mt-3 bl-text-small">
                        {{ __('main.goldGeneralInfo') }}
                    </h3>
                </div>
                <div class="tradingview-widget-container"
                    style="box-shadow: 0 8px 16px 0 rgb(10 14 29 / 2%), 0 8px 64px 0 rgb(119 119 119 / 8%);border-radius: 5px;">
                    <div class="tradingview-widget-container__widget"></div>
                    <div class="tradingview-widget-copyright"><a href="https://www.tradingview.com/" rel="noopener nofollow"
                            target="_blank"><span class="blue-text">Track all markets on TradingView</span></a></div>
                    <script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-symbol-overview.js"
                        async>
                        {
                            "symbols": [
                                [
                                    "OANDA:XAUUSD|1M"
                                ]
                            ],
                            "chartOnly": false,
                            "width": "100%",
                            "height": 400,
                            "locale": "{{ __('main.chart_locale') }}",
                            "colorTheme": "light",
                            "autosize": false,
                            "showVolume": false,
                            "showMA": false,
                            "hideDateRanges": false,
                            "hideMarketStatus": false,
                            "hideSymbolLogo": false,
                            "scalePosition": "right",
                            "scaleMode": "Normal",
                            "fontFamily": "-apple-system, BlinkMacSystemFont, Trebuchet MS, Roboto, Ubuntu, sans-serif",
                            "fontSize": "10",
                            "noTimeScale": false,
                            "valuesTracking": "1",
                            "changeMode": "price-and-percent",
                            "chartType": "area",
                            "maLineColor": "#2962FF",
                            "maLineWidth": 1,
                            "maLength": 9,
                            "gridLineColor": "rgba(242, 54, 69, 0.06)",
                            "backgroundColor": "rgba(255, 255, 255, 1)",
                            "lineWidth": 2,
                            "lineType": 0,
                            "dateRanges": [
                                "1d|1",
                                "1m|30",
                                "3m|60",
                                "12m|1D",
                                "60m|1W",
                                "all|1M"
                            ],
                            "timeHoursFormat": "12-hours"
                        }
                    </script>
                </div>
                </section>
            </div>
            <div class="col-12 col-lg-4 mb-5">
                @include('partials.__golden_egy_calculator')
                @include('components.egypt_central_bank')
            </div>

            <div class="col-12 mb-5">
                <h2 class="mb-3 text-center">{{ __('main.faq') }}</h2>
                <p class="text-center bl-text-small mt-3">{{ __('main.faqInfo') }}</p>
                <div class="accordion" id="accordionExample">
                    <div class="card accordion-item mb-2">
                        <h2 class="card-header p-0 ">
                            <button class="accordion-button" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseOne" aria-expanded="true" aria-controls="collapseOne">
                                {{ __('main.goldFirstQ') }}
                            </button>
                        </h2>
                        <div id="collapseOne" class="accordion-collapse collapse show" data-bs-parent="#accordionExample">
                            <div class="card-body">
                                {{ __('main.goldFirstAnswer', [
                                    'gold21' => $goldInFaq['karat-21'],
                                    'gold24' => $goldInFaq['karat-24'],
                                    'gold18' => $goldInFaq['karat-18'],
                                    'time' => $dateNow,
                                ]) }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection