<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.goldPrices'),
        'item' => \LaravelLocalization::localizeUrl(route('goldprice'))
    ],
    [
        '@type' => 'ListItem',
        'position' => 3,
        'name' => __('main.goldpricekarat', ['karat' => $goldKarat->name]),
    ]
]);
$metalPrice = \App\Models\MetalPrices::where('metal_type', 'XAU')->first();
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));

$keywords = __('main.gold_karat_keywords', ['karat' => $goldKarat->name]);
$keywordsText = implode(', ', $keywords);
$dateAdded = \Carbon\Carbon::parse($goldKarat->created_at)->format('Y-m-d\TH:i:s\Z');
$dateUpdated = \Carbon\Carbon::parse($goldKarat->updated_at)->format('Y-m-d\TH:i:s\Z');
$description =  __('main.gold_karat_desc', ['karat' => $goldKarat->name]);
$title = __('main.goldpricekarat', ['karat' => $goldKarat->name]);
?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description', $description)
@section('keywords', $keywordsText)
@section('article_tage')
<meta property="article:published_time" content="{{ $dateAdded }}">
<meta property="article:modified_time" content="{{ $dateUpdated }}">
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
<script type="application/ld+json">
    {
        "@context": "https://schema.org",
        "@type": "NewsArticle",
        "mainEntityOfPage": {
            "@type": "WebPage",
            "@id": "{{ route('gold_karat', ['karat' => $goldKarat->slug]) }}"
        },
        "headline": "{{ $title }}",
        "name": "{{ $title }}",
        "articleSection": "{{ __('main.goldPrices') }}",
        "image": {
            "@type": "ImageObject",
            "url": "{{ url('assets/img/bank_live_logo.png') }}",
            "width": 851,
            "height": 315
        },
        "datePublished": "{{ $dateAdded }}",
        "dateModified": "{{ $dateUpdated }}",
        "inLanguage": "{{ __('main.lang_country') }}",
        "keywords": "{{ $keywordsText }}",
        "author": {
            "@type": "Person",
            "name": "BankLive-news"
        },
        "publisher": {
        "@type": "Organization",
        "name": "{{ siteName() }}",
        "logo": {
            "@type": "ImageObject",
            "width": 190,
            "height": 60,
            "url": "{{ url('assets/favicons/android-icon-192x192.png') }}"
        }
        },
        "description": "{{ $description }}"
    }
    </script>
@endsection
@section('css')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <div class="row justify-content-between mt-5">
            <div class="col-12">
                <nav aria-label="breadcrumb mb-5 fs-6">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.goTo') }} {{ siteName() }}"
                                href="{{ url('/') }}" class="home">
                                <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.goldPrices') }}"
                                href="{{ route('goldprice') }}">
                                <span>{{ __('main.goldPrices') }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <span class="post post-post current-item">
                                {{ __('main.goldpricekarat', ['karat' => $goldKarat->name]) }} </span>
                        </li>
                    </ol>
                </nav>
            </div>
            <div class="col-12 col-lg-8 mb-5">
                <div class="my-2 text-start">
                    <h1 class="h1-page mx-0 mb-1 fw-bold fs-4">{{ __('main.price') }} {{ $goldKarat->name }} /
                        {{ __('main.egyPound') }}</h1>
                    <p class="text-start bl-text-small mt-3 mb-3">
                        {{ __('main.goldpricekaratInfo', ['karat' => $goldKarat->name, 'time' => $dateNow]) }}</p>
                </div>

                <div id="sectionMainPrice">
                    <section class="row" id="fast-price-info">
                        <div class="col-sm-12">
                            <div class="card my-3">
                                <div class="card-body">
                                    <div class="priceTypeFancyInfo start-0"> {{ __('main.last_move') }}
                                        {{ diffForHumans($goldKarat->price->updated_at) }}
                                        <div class="text-end font-lg-5 spinner-grow text-light spinner"></div>
                                    </div>
                                    <div class="d-flex justify-content-center align-items-baseline gap-3" id="priceData">
                                        <span
                                            class="color-main-price d-flex align-items-baseline ltr mainPagePrice fw-bold">
                                            {{ priceFormat($goldKarat->price->buy_price) }}
                                            <span class="bl-text-small">{{ __('main.egCurr') }}</span>
                                        </span>
                                        <div class="small ltr fs-5 {{ $goldKarat->price->buy_status }}">
                                            <i class="fas fa-arrow-{{ $goldKarat->price->buy_status }}"></i>
                                            {{ priceFormat($goldKarat->price->buy_change_percent) }}%
                                            {{-- {{ priceFormat($goldKarat->price->buy_change_amount) }} --}}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                
                <section id="morePrices">
                    <div class="row">
                        <div class="col-12 col-md-6">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span class="start-head bg-{{ statusBG($goldKarat->price->p_status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.price_sell') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($goldKarat->price->p_price) }}</span>
                                    <span class="fs-6 ltr {{ $goldKarat->price->p_status }}">
                                        <i class="fas fa-arrow-{{ $goldKarat->price->p_status }}"></i>
                                        {{ priceFormat($goldKarat->price->p_status_percentage) }}%
                                        {{-- {{ priceFormat($goldKarat->price->change_amount) }} --}}
                                    </span>
                                </div>
                            </div>
                        </div>

                        <div class="col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span
                                        class="start-head bg-{{ statusBG($previousClosuresPrice['status']) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.yesterdayClose') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($previousClosuresPrice['price']) }}</span>
                                    <span class="fs-6 ltr {{ $previousClosuresPrice['status'] }}">
                                        <i class="fas fa-arrow-{{ $previousClosuresPrice['status'] }}"></i>
                                        {{ priceFormat($previousClosuresPrice['change_percent']) }}%
                                        {{-- {{ priceFormat($previousClosuresPrice['change_amount']) }} --}}
                                    </span>
                                </div>
                            </div>
                        </div>

                        <div class="col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span class="start-head bg-{{ statusBG($goldOnzEgy->rate->buy_status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.ounce_local') }}</span>
                                    <span
                                        class="fs-4 fw-bold color-main-price">{{ priceFormat($goldOnzEgy->rate->buy_price) }}</span>
                                    <span class="fs-6 ltr {{ $goldOnzEgy->rate->buy_status }}">
                                        <i class="fas fa-arrow-{{ $goldOnzEgy->rate->buy_status }}"></i>
                                        {{ (int) priceFormat($goldOnzEgy->rate->buy_change_percent) }}%
                                        {{-- {{ priceFormat($goldOnzEgy->rate->buy_change_amount) }} --}}
                                    </span>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6 col-12">
                            <div class="py-1 px-3 my-2" style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                                <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                                    <span class="start-head bg-{{ statusBG($metalPrice->change_status) }} top-0"></span>
                                    <span class="fs-6">{{ __('main.ounce_global') }}</span>
                                    <span class="fs-4 fw-bold">${{ number_format($metalPrice->price, 2) }}
                                    </span>
                                    <span class="fs-6 ltr {{ $metalPrice->change_status }}">
                                        <i class="fas fa-arrow-{{ $metalPrice->change_status }}"></i>
                                        {{ priceFormat($metalPrice->change_percent, 5) }}%
                                    </span>
                                </div>
                            </div>
                        </div>

                    </div>
                </section>
                <div id="chartFilter" class="p-2 my-5">
                    <div class="py-2 d-flex flex-column gap-3">
                        <div class="d-flex align-items-center head">
                            <span class="start-head bg-danger top-0"></span>
                            <img src="{{asset('/assets/img/gold--icon.svg')}}" alt=""
                                class="rounded-5 ms-1" width="25" height="25">
                            <span class="mx-2 fs-6 opacity-75">
                                {{ __('main.price_archive') }} {{ $goldKarat->name }}
                            </span>
                        </div>
                        <form method="GET">
                            <div class="btn-group" role="group" aria-label="Duration selection">
                                <input type="hidden" name="days" id="days-input"
                                    value="{{ isset($filter) ? $filter : '7' }}">
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '7') active @endif"
                                    onclick="setDays(7)">{{ __('main.last7Days') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '30') active @endif"
                                    onclick="setDays(30)">{{ __('main.last30Days') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '90') active @endif"
                                    onclick="setDays(90)">{{ __('main.last3Months') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '180') active @endif"
                                    onclick="setDays(180)">{{ __('main.last6Months') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == '365') active @endif"
                                    onclick="setDays(365)">{{ __('main.lastYear') }}</button>
                                <button type="button"
                                    class="btn rounded-2 mx-1 px-2 py-1 btn-outline-danger btn-sm @if (isset($filter) && $filter == 'all') active @endif"
                                    onclick="setDays('all')">{{ __('main.all') }}</button>
                            </div>
                        </form>
                    </div>
                    <div style="width: 100%;overflow: hidden;position: relative;">
                        <canvas id="goldchart-id" height="300"
                            style="display: block; box-sizing: border-box; height: 346px; width: 693px;"></canvas>
                    </div>
                </div>

                <div class="mb-4">
                    <h2 class="text-start fs-4 fw-bold mb-0">
                        <span class="start-head bg-warning"></span> {{ __('main.moreGoldTypes') }}
                    </h2>
                </div>
                <div class="contai7ner-fluid">
                    <div class="swiper mySwiper goldListKarats">
                        <div class="swiper-wrapper">
                            @foreach ($gold_prices as $gold_price)
                                @if ($goldKarat->g_id == $gold_price->g_id)
                                    @continue
                                @endif
                                <div style="background: rgb(248 248 255 / 62%);"
                                    class="swiper-slide co7l-3 border border-light-subtle rounded-4 p-3">
                                    <a href="{{ $gold_price->fullUrl }}" class="text-decoration-none">
                                        <div class="align-items-center d-flex flex-row-reverse gap-2 justify-content-end">
                                            <h2 class="fs-6">
                                                {{ $gold_price->name }}
                                            </h2>
                                            <img style="border-radius: 50%; width: 25px; height: 25px;"src="{{asset('/assets/img/gold--icon.svg')}}"
                                                alt="">
                                        </div>
                                        <div
                                            class="flex-row-reverse align-items-baseline flex-row gap-3 justify-content-center d-flex ltr mt-3">
                                            <div class="fw-bold fs-4 color-main-price">
                                                {{ priceFormat($gold_price->rate->buy_price) }}
                                                <span class="bl-text-xs">{{ __('main.egCurr') }}</span>
                                            </div>
                                            <span dir="ltr"
                                                class="fw-normal ltr bl-text-sm {{ $gold_price->rate->buy_status }}">
                                                <i class="fas fa-arrow-{{ $gold_price->rate->buy_status }}"></i>
                                                {{ priceFormat($gold_price->rate->buy_change_percent) }}%</span>
                                        </div>
                                    </a>
                                </div>
                            @endforeach

                        </div>
                        <div class="swiper-button-next"></div>
                        <div class="swiper-button-prev"></div>
                    </div>

                </div>
            </div>
            <div class="col-12 mb-5 col-lg-4">
              @include('partials.__golden_egy_calculator')
              <div class="cur-convert-data mt-5">
                  <table class="table table-hover local-cur table-bordered rates-table">
                      <thead>
                          <tr>
                              <th class="fw-bold p-3">{{ __('main.karat_type') }}</th>
                              <th class="fw-bold p-3">{{ __('main.price') }}</th>
                          </tr>
                      </thead>
                      <tbody>
                          @foreach (getGaramsUntis() as $key => $value)
                              <tr class="p-3">
                                  <td class="fw-bold p-3">{{ $value }} @if ($goldKarat->is_gram)
                                          {{ __('main.gram') }}
                                      @endif {{ removeAlefLam($goldKarat->name) }} </td>
                                  <td class="fw-bold p-3">{{ priceFormat($goldKarat->price->buy_price * $value, 2) }}
                                      {{ __('main.egCurr') }}</td>
                              </tr>
                          @endforeach
                      </tbody>
                  </table>
              </div>

            </div>

            <div class="col-12 col-lg-8 mb-5">
                <div class="mb-4">
                    <h2 class="text-start fs-4 fw-bold mb-0">
                        <span class="start-head bg-warning"></span> {{ __('main.goldGeneral') }}
                    </h2>
                    <h3 class="text-start mt-3 bl-text-small">
                        {{ __('main.goldGeneralInfo') }}
                    </h3>
                </div>
                <div class="tradingview-widget-container"
                    style="box-shadow: 0 8px 16px 0 rgb(10 14 29 / 2%), 0 8px 64px 0 rgb(119 119 119 / 8%);border-radius: 5px;">
                    <div class="tradingview-widget-container__widget"></div>
                    <script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-symbol-overview.js"
                        async>
                        {
                            "symbols": [
                                [
                                    "OANDA:XAUUSD|1M"
                                ]
                            ],
                            "chartOnly": false,
                            "width": "100%",
                            "height": 400,
                            "locale": "{{ __('main.chart_locale') }}",
                            "colorTheme": "light",
                            "autosize": false,
                            "showVolume": false,
                            "showMA": false,
                            "hideDateRanges": false,
                            "hideMarketStatus": false,
                            "hideSymbolLogo": false,
                            "scalePosition": "right",
                            "scaleMode": "Normal",
                            "fontFamily": "-apple-system, BlinkMacSystemFont, Trebuchet MS, Roboto, Ubuntu, sans-serif",
                            "fontSize": "10",
                            "noTimeScale": false,
                            "valuesTracking": "1",
                            "changeMode": "price-and-percent",
                            "chartType": "area",
                            "maLineColor": "#2962FF",
                            "maLineWidth": 1,
                            "maLength": 9,
                            "gridLineColor": "rgba(242, 54, 69, 0.06)",
                            "backgroundColor": "rgba(255, 255, 255, 1)",
                            "lineWidth": 2,
                            "lineType": 0,
                            "dateRanges": [
                                "1d|1",
                                "1m|30",
                                "3m|60",
                                "12m|1D",
                                "60m|1W",
                                "all|1M"
                            ],
                            "timeHoursFormat": "12-hours"
                        }
                    </script>
                </div>
            </div>
            <div class="col-12 col-lg-4 mb-5">
                @include('components.egypt_central_bank')
            </div>
            {{-- <div class="col-12 mb-5">
                  <h2 class="mb-3 text-center">{{ __('main.faq') }}</h2>
                  <p class="text-center bl-text-small mt-3">{{ __('main.faqInfo') }}</p>
                    <div class="accordion" id="accordionExample">
                        <div class="card accordion-item mb-2">
                          <h2 class="card-header p-0 ">
                            <button class="accordion-button" type="button" data-bs-toggle="collapse" data-bs-target="#collapseOne" aria-expanded="true" aria-controls="collapseOne">
                                {{ __('main.goldFirstQ') }}
                            </button>
                          </h2>
                          <div id="collapseOne" class="accordion-collapse collapse show" data-bs-parent="#accordionExample">
                            <div class="card-body">
                              {{ __('main.goldFirstAnswer', [
                                'gold21' => $goldInFaq['karat-21'],
                                'gold24' => $goldInFaq['karat-24'],
                                'gold18' => $goldInFaq['karat-18'],
                                'time' => $dateNow,
                              ]) }}
                            </div>
                          </div>
                        </div> --}}
            {{-- <div class="card accordion-item mb-2">
                          <h2 class="card-header p-0 ">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseTwo" aria-expanded="false" aria-controls="collapseTwo">
                              Accordion Item #2
                            </button>
                          </h2>
                          <div id="collapseTwo" class="accordion-collapse collapse" data-bs-parent="#accordionExample">
                            <div class="card-body">
                              <strong>This is the second item's accordion body.</strong> It is hidden by default, until the collapse plugin adds the appropriate classes that we use to style each element. These classes control the overall appearance, as well as the showing and hiding via CSS transitions. You can modify any of this with custom CSS or overriding our default variables. It's also worth noting that just about any HTML can go within the <code>.card-body</code>, though the transition does limit overflow.
                            </div>
                          </div>
                        </div>
                        <div class="card accordion-item mb-2">
                          <h2 class="card-header p-0 ">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
                              Accordion Item #3
                            </button>
                          </h2>
                          <div id="collapseThree" class="accordion-collapse collapse" data-bs-parent="#accordionExample">
                            <div class="card-body">
                              <strong>This is the third item's accordion body.</strong> It is hidden by default, until the collapse plugin adds the appropriate classes that we use to style each element. These classes control the overall appearance, as well as the showing and hiding via CSS transitions. You can modify any of this with custom CSS or overriding our default variables. It's also worth noting that just about any HTML can go within the <code>.card-body</code>, though the transition does limit overflow.
                            </div>
                          </div>
                        </div>
                      </div>
                </div> --}}
        </div>
    </div>
@endsection
@section('js')
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script type="text/javascript">
        var swiper = new Swiper(".goldListKarats", {
            slidesPerView: 4,
            spaceBetween: 10,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            navigation: {
                nextEl: ".swiper-button-next",
                prevEl: ".swiper-button-prev",
            },
            freeMode: true,
            breakpoints: {
                900: {
                    slidesPerView: 3,
                },
                768: {
                    slidesPerView: 2,
                },
                576: {
                    slidesPerView: 1,
                },
                350: {
                    slidesPerView: 1,
                },
                0: {
                    slidesPerView: 1,
                },
            }
        });



        document.addEventListener("DOMContentLoaded", () => {
            setTimeout(function() {


                const plugin = {
                    id: 'verticalLiner',
                    afterInit: (chart, args, opts) => {
                        chart.verticalLiner = {}
                    },
                    afterEvent: (chart, args, options) => {
                        const {
                            inChartArea
                        } = args
                        chart.verticalLiner = {
                            draw: inChartArea
                        }
                    },
                    beforeTooltipDraw: (chart, args, options) => {
                        const {
                            draw
                        } = chart.verticalLiner
                        if (!draw) return

                        const {
                            ctx
                        } = chart
                        const {
                            top,
                            bottom
                        } = chart.chartArea
                        const {
                            tooltip
                        } = args
                        const x = tooltip?.caretX
                        if (!x) return

                        ctx.save()
                        ctx.lineWidth = 1;
                        ctx.strokeStyle = '#DDD';
                        ctx.beginPath()
                        ctx.moveTo(x, top)
                        ctx.lineTo(x, bottom)
                        ctx.stroke()
                        ctx.restore()
                    }
                }


                let myChart = new Chart(document.getElementById('goldchart-id').getContext('2d'), {
                    type: 'line',
                    data: {
                        labels: [
                            @foreach ($getArchivePrices['dates'] as $date)
                                "{{ $date }}",
                            @endforeach
                        ],
                        datasets: [{
                            label: "#{{ __('main.price') }}",
                            data: [
                                @foreach ($getArchivePrices['prices'] as $price)
                                    "{{ $price }}",
                                @endforeach
                            ],
                            backgroundColor: "#f3a12188",
                            borderColor: '#ff9800',
                            pointStyle: 'rect',

                            lineTension: '.15',
                            tension: 0.1,
                            fill: true,
                            pointStyle: "circle",
                            pointBorderColor: "#ff9800",
                            pointBackgroundColor: "#fff",
                            pointRadius: 1,
                            borderWidth: 2.5,
                        }]
                    },
                    plugins: [plugin],

                    options: {
                        responsive: true,
                        interaction: {
                            intersect: false,
                            mode: 'index',
                            axis: 'x'
                        },
                        plugins: {
                            legend: {
                                display: false,
                                labels: {
                                    font: {
                                        size: 14,
                                        family: "dubai"
                                    }
                                }
                            }
                        },
                        scales: {
                            x: {
                                ticks: {
                                    autoSkip: true,
                                    maxTicksLimit: 3
                                },
                                // display:false,
                                beginAtZero: false,
                                grid: {
                                    display: false
                                }
                            },
                            y: {
                                grid: {
                                    display: true,
                                    color: "rgb(3,169,244,0.05)"
                                }
                            },

                        },
                        hover: {
                            mode: 'index'
                        },
                        legend: {
                            labels: {

                                fontFamily: 'dubai',
                                defaultFontFamily: 'dubai',
                            }
                        },
                        elements: {
                            line: {
                                tension: 1
                            }
                        }
                    }
                });
            }, 500);
        });
    </script>
@endsection
