<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.petroleumPrices'),
    ]
]);
// $metalPrice = \App\Models\MetalPrices::where('metal_type', 'XAU')->first();
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$currentDay = \Carbon\Carbon::now()->isoFormat('dddd D-M-YYYY');
?>
@extends('app')
@section('title', __('main.fuel_title'))
@section('type', 'article')
@section('description', __('main.fuel_desc'))
@section('keywords', __('main.fuel_keywords'))
@section('content')
    <div class="container my-5 text-center text-md-start">
        <nav aria-label="breadcrumb mb-5 fs-6">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a title="{{ __('main.goTo') }} {{ siteName() }}"
                        href="{{ url('/') }}" class="home">
                        <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                    </a>
                </li>
                <li class="breadcrumb-item active" aria-current="page">
                    <span class="post post-post current-item">
                        {{ __('main.petroleumPrices') }} </span>
                </li>
            </ol>
        </nav>
        <div class="my-5" id="mainTitle">
            <h1 class="text-center fw-bold fs-1">{{ __('main.fuel_title') }}</h1>
            <span class="text-center d-block mb-5">{{ __('main.timeNow') }}{{ $dateNow }}</span>
        </div>
        <div class="row justify-content-between mt-5">
            <div class="col-12 col-lg-8 mb-5">
                <table class="banklive-table petrol table table-hover text-center">
                    <thead>
                        <tr>
                            <th>{{ __('main.unit') }}</th>
                            <th>{{ __('main.price') }}</th>
                            <th>{{ __('main.change') }}</th>
                        </tr>
                    </thead>
                    <tbody>

                        @foreach ($petroleumPrice as $petrol)
                            <td class="text-center petrol-type fs-5">
                                <a href="{{ lurl(route('petrolUnit', ['slug' => $petrol->types->slug])) }}"
                                    title="{{ __('main.fuel_unit_title', ['name' => $petrol->types->name]) }}">
                                    <span class="gasIcon">{!! $petrol->types->icon !!}</span>
                                    {{ $petrol->types->name }}
                                </a>
                            </td>
                            <td class="text-center petrol-rate fs-5">{{ number_format($petrol->price, 2) }}</td>
                            <td class="text-center ltr petrol-change fw-bold {{ $petrol->change_type }}">
                                <i class="fas fa-arrow-{{ $petrol->change_type }}"></i>
                                <span>{{ number_format(priceFormat($petrol->change_amount, 4), 2) }}</span>
                                (<span>{{ priceFormat($petrol->change_percentage, 2) }}%</span>)
                                </tr>
                        @endforeach
                    </tbody>
                </table>
                <p class="text-muted text-center opacity-75 mt-4">
                    {{ __('main.fuel_desc') }}
                </p>
            </div>
            <div class="col-12 mb-5 col-lg-4">
                @include('partials.__petrol_egy_calculator')
            </div>
            <div class="col-12 col-lg-8 mb-5">
                <div class="faq">
                    <h2 class="mb-3 text-center">{{ __('main.faq') }}</h2>
                    <p class="text-center bl-text-small mt-3">{{ __('main.faqInfo') }}</p>
                    @foreach ($petroleumPrice as $key => $petrol)
                        <div class="accordion" id="accordionExample-1{{ $key }}">
                            <div class="card accordion-item mb-2">
                                <h2 class="card-header p-0 ">
                                    <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                        data-bs-target="#collapse-1{{ $key }}" aria-expanded="false"
                                        aria-controls="collapse-1{{ $key }}">
                                        {{ __('main.faq_question', ['type' => $petrol->types->name]) }}
                                    </button>
                                </h2>
                                <div id="collapse-1{{ $key }}" class="accordion-collapse collapsed collapse"
                                    data-bs-parent="#accordionExample-1{{ $key }}">
                                    <div class="card-body text-start">
                                        <p class="text-start">
                                            {{ __('main.faq_price_today', ['type' => $petrol->types->name, 'date' => $currentDay, 'price' => $petrol->price]) }}
                                        </p>
                                        <p class="text-start">
                                            {{ __('main.faq_price_change', ['status' => __('main.in_de_' . $petrol->change_type), 'change_type' => __('main.' . $petrol->change_type), 'change_amount' => $petrol->change_amount, 'change_percentage' => $petrol->change_percentage]) }}
                                        </p>
                                        <p class="text-start">
                                            {{ __('main.faq_last_update', ['last_update' => $petrol->updated_at->isoFormat('dddd D-M-YYYY')]) }}
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
            <div class="col-12 col-lg-4 mb-5">
                @include('components.egypt_central_bank')
            </div>
        </div>
    </div>
@endsection
@section('js')
    @php
    foreach ($petroleumPrice as $key => $petrol) {
        $faq[] = [
            "question" => strip_tags(__('main.faq_question', ['type' => $petrol->types->name])),
            "answer" => str_replace(["\n", "\r"], '', strip_tags(
                __('main.faq_price_today', ['type' => $petrol->types->name, 'date' => $currentDay, 'price' => $petrol->price]) . "\n" .
                __('main.faq_price_change', ['status' => __('main.in_de_' . $petrol->change_type), 'change_type' => __('main.' . $petrol->change_type), 'change_amount' => $petrol->change_amount, 'change_percentage' => $petrol->change_percentage]) . "\n" .
                __('main.faq_last_update', ['last_update' => $petrol->updated_at->isoFormat('dddd D-M-YYYY')])
            ))
        ];
    }
    $faqSchema = [
        "@context" => "https://schema.org",
        "@type" => "FAQPage",
        "mainEntity" => []
    ];

    foreach ($faq as $item) {
        $faqSchema["mainEntity"][] = [
            "@type" => "Question",
            "name" => $item["question"],
            "acceptedAnswer" => [
                "@type" => "Answer",
                "text" => $item["answer"]
            ]
        ];
    }
    $jsonLdFaq = json_encode($faqSchema, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
    @endphp
    <script type="application/ld+json">
        {!! $jsonLdFaq !!}
    </script>
@endsection