<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/'),
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.petroleumPrices'),
        'item' => lurl(route('petrol')),
    ],
    [
        '@type' => 'ListItem',
        'position' => 3,
        'name' => __('main.fuel_unit_title', ['name' => $petroleumPrice->name]),
    ],
]);
// $metalPrice = \App\Models\MetalPrices::where('metal_type', 'XAU')->first();
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$updated_at = \Carbon\Carbon::parse($petroleumPrice->rate->updated_at)->format('Y-m-d');
$keywords = __('main.new_gasoline_keywords', ['gasolineType' => $petroleumPrice->name, 'year' => now()->year]);
$keywordsText = implode(', ', $keywords);
$dateAdded = '2022-07-14T00:00:00+0300';
$dateUpdated = now()->format('Y-m-d\TH:i:s\Z');
$description =  __('main.fuel_unit_desc', ['name' => $petroleumPrice->name]);
$title = __('main.fuel_unit_title', ['name' => $petroleumPrice->name]);
?>
@extends('app')
@section('title', $title)
@section('type', 'article')
@section('description', $description)
@section('keywords', $keywordsText)
@section('article_tage')
<meta property="article:published_time" content="{{ $dateAdded }}">
<meta property="article:modified_time" content="{{ $dateUpdated }}">
@foreach ($keywords as $tag)
<meta property="article:tag" content="{{ $tag }}" />
@endforeach
<script type="application/ld+json">
{
    "@context": "https://schema.org",
    "@type": "NewsArticle",
    "mainEntityOfPage": {
        "@type": "WebPage",
        "@id": "{{ route('petrolUnit', ['slug' => $petroleumPrice->slug]) }}"
    },
    "headline": "{{ $title }}",
    "name": "{{ $title }}",
    "articleSection": "{{ __('main.petroleumPrices') }}",
    "image": {
        "@type": "ImageObject",
        "url": "{{ url('assets/img/bank_live_logo.png') }}",
        "width": 851,
        "height": 315
    },
    "datePublished": "{{ $dateAdded }}",
    "dateModified": "{{ $dateUpdated }}",
    "inLanguage": "{{ __('main.lang_country') }}",
    "keywords": "{{ $keywordsText }}",
    "author": {
        "@type": "Person",
        "name": "BankLive-news"
    },
    "publisher": {
    "@type": "Organization",
    "name": "{{ siteName() }}",
    "logo": {
        "@type": "ImageObject",
        "width": 190,
        "height": 60,
        "url": "{{ url('assets/favicons/android-icon-192x192.png') }}"
    }
    },
    "description": "{{ $description }}"
}
</script>
@endsection
@section('css')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <div class="row justify-content-between mt-5">
            <div class="col-12">
                <nav aria-label="breadcrumb mb-5 fs-6">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.goTo') }} {{ siteName() }}" href="{{ url('/') }}" class="home">
                                <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item">
                            <a title="{{ __('main.petroleumPrices') }}" href="{{ lurl(route('petrol')) }}">
                                <span>{{ __('main.petroleumPrices') }}</span>
                            </a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <span class="post post-post current-item">
                                {{ __('main.fuel_unit_title', ['name' => $petroleumPrice->name]) }}</span>
                        </li>
                    </ol>
                </nav>
            </div>
            <div class="col-12 col-lg-8">
                <div class="my-2 text-start">
                    <h1 class="h1-page mx-0 mb-1 fw-bold fs-4">{!! $petroleumPrice->icon !!} {{ __('main.price') }}
                        {{ $petroleumPrice->name }} / {{ __('main.egyPound') }}</h1>
                    <p class="text-start bl-text-small mt-3 mb-3">
                        {{ __('main.fuel_unit_desc', ['name' => $petroleumPrice->name]) }} {{ $dateNow }}</p>
                </div>
                <div id="sectionMainPrice">
                    <section class="row" id="fast-price-info">
                        <div class="col-sm-12">
                            <div class="card my-3 petrol">
                                <div class="card-body">
                                    <div class="priceTypeFancyInfo">{{ __('main.last_move') }} {{ $updated_at }}
                                        <div class="font-1 text-end font-lg-5 spinner-grow text-light spinner"></div>
                                    </div>
                                    <div class="d-flex justify-content-center align-items-baseline gap-3" id="priceData">
                                        <span
                                            class="color-main-price d-flex align-items-baseline ltr mainPagePrice fw-bold">
                                            {{ $petroleumPrice->rate->price }}
                                            <span class="bl-text-small">{{ __('main.egCurr') }}</span>
                                        </span>
                                        <div class="small ltr fs-5 {{ $petroleumPrice->rate->change_type }}">
                                            <i class="fas fa-arrow-{{ $petroleumPrice->rate->change_type }}"></i>
                                            {{ $petroleumPrice->rate->change_percentage }}%
                                            {{ $petroleumPrice->rate->change_amount }}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                @php
                    $bg = $previousClosuresPrice['status'] == 'down' ? 'danger' : 'success';
                @endphp
                <div id="morePrices" class="d-table justify-content-center align-items-center gap-4 mx-auto mx-auto"
                    style="box-shadow:rgba(0, 17, 51, 0.07) 0px 3px 15px;">
                    <div class="item text-start fs-5 align-items-center gap-2 mb-0 d-flex">
                        <span class="start-head bg-{{ $bg }} top-0"></span>
                        <span class="fs-6">{{ __('main.lastClose') }}</span>
                        <span class="fs-4 fw-bold color-main-price">{{ $previousClosuresPrice['price'] }}</span>
                        <span class="fs-6 ltr {{ $previousClosuresPrice['status'] }}">
                            <i class="fas fa-arrow-{{ $previousClosuresPrice['status'] }}"></i>
                            {{ number_format(priceFormat($previousClosuresPrice['change_percent'], 2), 2) }}%
                            {{ number_format(priceFormat($previousClosuresPrice['change_amount'], 2), 2) }}
                        </span>
                    </div>
                </div>


                <div id="chartFilter" class="p-2 my-5">
                    <div class="py-2 d-flex flex-column gap-3">
                        <div class="d-flex align-items-center head">
                            <span class="start-head bg-danger top-0"></span>
                            <span class="ms-1">{!! $petroleumPrice->icon !!}</span>
                            <span class="mx-2 fs-6 opacity-75">
                                {{ __('main.archivePrices', ['karat' => $petroleumPrice->name]) }}
                            </span>
                        </div>
                    </div>
                    <div style="width: 100%;overflow: hidden;position: relative;">
                        <canvas id="goldchart-id" height="300"
                            style="z-index: 1;display: block; box-sizing: border-box; height: 346px; width: 693px;"></canvas>
                    </div>
                </div>

                <div id="moreItems">
                    <div class="mb-4">
                        <h2 class="text-start fs-4 fw-bold mb-0">
                            <span class="start-head bg-danger"></span>
                            <i class="fas fa-gas-pump"></i>
                            {{ __('main.more_of_gasoline') }}
                        </h2>
                    </div>
                    <div class="contai7ner-fluid">
                        <div class="swiper mySwiper goldListKarats">
                            <div class="swiper-wrapper">
                                @foreach ($allGasPrices as $gas)
                                    @if ($petroleumPrice->id == $gas->id)
                                        @continue
                                    @endif
                                    <div style="background: rgb(248 248 255 / 62%);"
                                        class="swiper-slide co7l-3 border border-light-subtle rounded-4 p-3">
                                        <a href="{{ route('petrolUnit', ['slug' => $gas->types->slug]) }}"
                                            class="text-decoration-none">
                                            <div
                                                class="align-items-center d-flex flex-row-reverse gap-2 justify-content-end">
                                                <h2 class="fs-6">
                                                    {{-- {{ __('main.' . $gas->types->unit_type) }}  --}}
                                                    {{-- <div class="from"></div> --}}
                                                    {{ $gas->types->name }}
                                                    {{-- <div class="to">/ {{ __('main.EGP') }}</div> --}}
                                                </h2>
                                                <div class="iconGas">
                                                    {!! $gas->types->icon !!}
                                                </div>
                                            </div>
                                            <div
                                                class="flex-row-reverse align-items-baseline flex-row gap-3 justify-content-center d-flex ltr mt-3">
                                                <div class="fw-bold fs-4 color-main-price">{{ $gas->price }}
                                                    <span class="bl-text-xs">{{ __('main.egCurr') }}</span>
                                                </div>
                                                <span dir="ltr"
                                                    class="fw-normal up ltr bl-text-sm {{ $gas->change_status }}">
                                                    <i class="fas fa-arrow-{{ $gas->change_status }}"></i>
                                                    {{ $gas->change_percentage }}%</span>
                                            </div>
                                        </a>
                                    </div>
                                @endforeach
                            </div>
                            <div class="swiper-button-next"></div>
                            <div class="swiper-button-prev"></div>
                        </div>
                    </div>
                </div>
                <div class="faq mt-5">
                    <h2 class="mb-3 fs-5 text-center">{{ __('main.faq') }}</h2>
                    <p class="text-center bl-text-xs mt-3">{{ __('main.faqInfo') }}</p>
                    @foreach (__('main.fuelDatQA') as $index => $item)
                        <div class="accordion" id="accordionExample{{ $index }}">
                            <div class="card accordion-item mb-2">
                                <h2 class="card-header p-0 ">
                                    <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                        data-bs-target="#collapse{{ $index }}" aria-expanded="false"
                                        aria-controls="collapse{{ $index }}">
                                        {{ $item['question'] }}
                                    </button>
                                </h2>
                                <div id="collapse{{ $index }}" class="accordion-collapse collapsed collapse"
                                    data-bs-parent="#accordionExample{{ $index }}">
                                    <div class="card-body">
                                        {{ $item['answer'] }}
                                    </div>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
            <div class="col-12 col-lg-4">
                @include('partials.__petrol_egy_calculator')
                <div class="cur-convert-data mt-5">
                    <table class="table table-hover banklive-table">
                        <thead>
                            <tr>
                                <th class="fw-bold p-3">{{ __('main.litr_types') }}</th>
                                <th class="fw-bold p-3">{{ __('main.price') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ([1, 20, 30, 40, 50, 60] as $key => $value)
                                <tr class="p-3">
                                    <td class="fw-bold p-3">{{ $value }}
                                        {{ __('main.' . $petroleumPrice->unit_type) }}
                                        {{ removeAlefLam($petroleumPrice->name) }} </td>
                                    <td class="fw-bold p-3">{{ priceFormat($petroleumPrice->rate->price * $value, 2) }}
                                        {{ __('main.egCurr') }}</td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
                <div class="col-12">
                    @include('components.egypt_central_bank')
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js')
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script type="text/javascript">
        var swiper = new Swiper(".goldListKarats", {
            slidesPerView: 4,
            spaceBetween: 10,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            navigation: {
                nextEl: ".swiper-button-next",
                prevEl: ".swiper-button-prev",
            },
            freeMode: true,
            breakpoints: {
                900: {
                    slidesPerView: 3,
                },
                768: {
                    slidesPerView: 2,
                },
                576: {
                    slidesPerView: 1,
                },
                350: {
                    slidesPerView: 1,
                },
                0: {
                    slidesPerView: 1,
                },
            }
        });

        document.addEventListener("DOMContentLoaded", () => {
            setTimeout(function() {


                const plugin = {
                    id: 'verticalLiner',
                    afterInit: (chart, args, opts) => {
                        chart.verticalLiner = {}
                    },
                    afterEvent: (chart, args, options) => {
                        const {
                            inChartArea
                        } = args
                        chart.verticalLiner = {
                            draw: inChartArea
                        }
                    },
                    beforeTooltipDraw: (chart, args, options) => {
                        const {
                            draw
                        } = chart.verticalLiner
                        if (!draw) return

                        const {
                            ctx
                        } = chart
                        const {
                            top,
                            bottom
                        } = chart.chartArea
                        const {
                            tooltip
                        } = args
                        const x = tooltip?.caretX
                        if (!x) return

                        ctx.save()
                        // تحديد خصائص الخط هنا
                        ctx.lineWidth = 1; // سماكة الخط
                        ctx.strokeStyle = '#87b6d9'; // لون الخط

                        ctx.beginPath()
                        ctx.moveTo(x, top)
                        ctx.lineTo(x, bottom)
                        ctx.stroke()
                        ctx.restore()
                    }
                }


                const watermarkPlugin = {
                    id: 'watermark',
                    afterDraw: (chart, args, options) => {
                        const ctx = chart.ctx;
                        ctx.save();

                        ctx.font = "30px Arial";
                        ctx.fillStyle = "rgba(0, 0, 0, 0.1)";
                        ctx.textAlign = "left";
                        ctx.textBaseline = "bottom";


                        const boldText = "Banklive";
                        const normalText = "net.";
                        const boldWidth = ctx.measureText(boldText).width;
                        const normalWidth = ctx.measureText(normalText).width;

                        // رسم النص بخصائصه المطلوبة
                        ctx.font = "bold 30px Arial"; // تعيين النص بنمط الخط العريض
                        ctx.fillText(boldText, 50, 50);

                        ctx.font = "normal 20px Arial"; // تعيين النص بنمط الخط العادي
                        ctx.fillText(normalText, 60 + boldWidth, 45);
                        ctx.restore();
                    }
                };
                let myChart = new Chart(document.getElementById('goldchart-id').getContext('2d'), {
                    type: 'line',
                    data: {
                        labels: [
                            @foreach ($getArchivePrices['dates'] as $date)
                                "{{ $date }}",
                            @endforeach
                        ],
                        datasets: [{
                            label: '# السعر',
                            data: [
                                @foreach ($getArchivePrices['prices'] as $price)
                                    "{{ $price }}",
                                @endforeach
                            ],
                            backgroundColor: "#e5eff5",
                            borderColor: '#87b6d9',
                            //   pointStyle: 'rect',

                            //   lineTension: '.15',
                            tension: 0.1,
                            fill: true,
                            //   pointStyle: "circle",
                            //   pointBorderColor: "#ff9800",
                            //   pointBackgroundColor: "#fff",
                            //   pointRadius: 1,
                            //   borderWidth: 2.5,
                        }]
                    },
                    plugins: [plugin, watermarkPlugin],

                    options: {
                        responsive: true,
                        interaction: {
                            intersect: false,
                            mode: 'index',
                            axis: 'x'
                        },
                        plugins: {
                            legend: {
                                display: false,
                                labels: {
                                    font: {
                                        size: 14,
                                        family: "dubai"
                                    }
                                }
                            }
                        },
                        scales: {
                            x: {
                                ticks: {
                                    autoSkip: true,
                                    maxTicksLimit: 3
                                },
                                // display:false,
                                beginAtZero: false,
                                grid: {
                                    display: false
                                }
                            },
                            y: {
                                grid: {
                                    display: true,
                                    color: "rgb(3,169,244,0.05)"
                                }
                            },

                        },
                        hover: {
                            mode: 'index'
                        },
                        legend: {
                            labels: {

                                fontFamily: 'dubai',
                                defaultFontFamily: 'dubai',
                            }
                        },
                        elements: {
                            line: {
                                tension: 1
                            }
                        }
                    }
                });

            }, 500);
        });
    </script>
@endsection
