<?php
\Artesaos\SEOTools\Facades\JsonLd::setType('BreadcrumbList');
\Artesaos\SEOTools\Facades\JsonLd::addValue('itemListElement', [
    [
        '@type' => 'ListItem',
        'position' => 1,
        'name' => siteName(),
        'item' => \LaravelLocalization::localizeUrl('/')
    ],
    [
        '@type' => 'ListItem',
        'position' => 2,
        'name' => __('main.silverByMoment'),
    ]
]);
$metalPrice = \App\Models\MetalPrices::where('currency', 'USD')->where('metal_type', 'XAG')->first();
$metalPriceEgp = \App\Models\MetalPrices::where('currency', 'EGP')->where('metal_type', 'XAG')->first();
$dateNow = \Carbon\Carbon::now()->locale(config('app.locale'))->translatedFormat(__('main.time_format'));
$currentDay = \Carbon\Carbon::now()->isoFormat('dddd D-M-YYYY');
?>
@extends('app')
@section('title')
    {{ __('main.silver_title') }}
@endsection
@section('type')
    article
@endsection
@section('description')
    {{ __('main.silver_desc') }}
@endsection
@section('keywords')
    اسعار الفضة في مصر, Silver price in egypt today, سعر جرامات الفضة اليوم, Gram Silver price in egypt
@endsection
@section('content')
    <div class="container my-5 text-center text-md-start">
        <nav aria-label="breadcrumb mb-5 fs-6">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a title="{{ __('main.goTo') }} {{ siteName() }}"
                        href="{{ url('/') }}" class="home">
                        <span><i class="fas fa-home"></i> {{ siteName() }}</span>
                    </a>
                </li>
                <li class="breadcrumb-item active" aria-current="page">
                    <span class="post post-post current-item">
                        {{ __('main.silverByMoment') }} </span>
                </li>
            </ol>
        </nav>
        <div class="my-5" id="mainTitle">
            <h1 class="text-center fw-bold fs-1">{{ __('main.silver_title') }}</h1>
            <span class="text-center d-block mb-5">{{ __('main.timeNow') }}{{ $dateNow }}</span>
        </div>
        <div class="row justify-content-between mt-5">
            <div class="col-12 col-lg-8 mb-5">
                <table class="banklive-table table table-hover text-center">
                    <thead>
                        <tr>
                            <th>{{ __('main.unit') }}</th>
                            <th>{{ __('main.price_eg') }}</th>
                            <th>{{ __('main.price_usd') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td class="text-center fs-6">{{ __('main.us_gold_onz_price') }}</td>
                            <td class="text-center">
                                <span dir="ltr">
                                    <div class="couwnt fs-6 fw-bold">{{ priceFormat($metalPriceEgp->price) }}</div>
                                    <div class="small {{ $metalPriceEgp->change_status }}">
                                        <i class="fas fa-arrow-{{ $metalPriceEgp->change_status }}"></i>
                                        {{ priceFormat($metalPriceEgp->change_percent, 10) }}%
                                    </div>
                                </span>
                            </td>
                            <td class="text-center  price_{{ $metalPrice->p_status }}">
                                <span dir="ltr">
                                    <div class="couwnt fs-6 fw-bold">${{ priceFormat($metalPrice->price) }}</div>
                                    <div class="small {{ $metalPrice->change_status }}">
                                        ({{ priceFormat($metalPrice->change_percent, 4) }}%)</div>
                                </span>
                            </td>
                        </tr>
                        @foreach ($silver_prices as $silver)
                            <tr>
                                <td class="text-center  fs-6"><a
                                        href="{{ route('silver_karat', ['karat' => $silver->kind->slug]) }}"
                                        title="{{ $silver->kind->name }}">{{ $silver->kind->name }}</a></td>
                                <td class="text-center">
                                    <span dir="ltr">
                                        <div class="fs-6  fw-bold">{{ $silver->p_price }}</div>
                                        <div class="small {{ $silver->change_status }}">
                                            ({{ rounded($silver->change_percentage) }}%)</div>
                                    </span>
                                </td>
                                <td class="text-center price_{{ $silver->p_status }}">
                                    <span dir="ltr">
                                        <div class="fs-6 fw-bold">${{ $silver->usd_price }}</div>
                                        <div class="small {{ $silver->usd_change_status }}">
                                            ({{ rounded($silver->usd_change_percentage) }}%)</div>
                                    </span>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
                <p class="font-1 opacity-50 fw-light text-center mt-4">
                    {{ __('main.silver_desc_meta') }} {{ __('main.last_update') }}
                    {{ $silver->updated_at->diffForHumans() }}
                    {{-- {!! __('main.silver_page_desc') !!} --}}
                </p>


                <div class="col-12  my-5">
                    <div class="mb-4">
                        <h2 class="text-start font-3 mb-0">
                            <span class="start-head" style="background: silver;"></span> {{ __('main.silverGeneral') }}
                        </h2>
                        <h3 class="text-start mt-3 bl-text-small">
                            {{ __('main.silverGeneralInfo') }}
                        </h3>
                    </div>
                    <div class="tradingview-widget-container"
                        style="box-shadow: 0 8px 16px 0 rgb(10 14 29 / 2%), 0 8px 64px 0 rgb(119 119 119 / 8%);border-radius: 5px;">
                        <div class="tradingview-widget-container__widget"></div>
                        <div class="tradingview-widget-copyright"><a href="https://www.tradingview.com/"
                                rel="noopener nofollow" target="_blank"><span class="blue-text">Track all markets on
                                    TradingView</span></a></div>
                        <script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-symbol-overview.js"
                            async>
                            {
                                "symbols": [
                                    [
                                        "OANDA:XAGUSD|1M"
                                    ]
                                ],
                                "chartOnly": false,
                                "width": "100%",
                                "height": 400,
                                "locale": "{{ __('main.chart_locale') }}",
                                "colorTheme": "light",
                                "autosize": false,
                                "showVolume": false,
                                "showMA": false,
                                "hideDateRanges": false,
                                "hideMarketStatus": false,
                                "hideSymbolLogo": false,
                                "scalePosition": "right",
                                "scaleMode": "Normal",
                                "fontFamily": "-apple-system, BlinkMacSystemFont, Trebuchet MS, Roboto, Ubuntu, sans-serif",
                                "fontSize": "10",
                                "noTimeScale": false,
                                "valuesTracking": "1",
                                "changeMode": "price-and-percent",
                                "chartType": "area",
                                "maLineColor": "#2962FF",
                                "maLineWidth": 1,
                                "maLength": 9,
                                "gridLineColor": "rgba(242, 54, 69, 0.06)",
                                "backgroundColor": "rgba(255, 255, 255, 1)",
                                "lineWidth": 2,
                                "lineType": 0,
                                "dateRanges": [
                                    "1d|1",
                                    "1m|30",
                                    "3m|60",
                                    "12m|1D",
                                    "60m|1W",
                                    "all|1M"
                                ],
                                "timeHoursFormat": "12-hours"
                            }
                        </script>
                    </div>
                </div>
            </div>
            <div class="col-12 mb-5 col-lg-4">
                @include('partials.__silver_egy_calculator')
                @include('components.egypt_central_bank')
            </div>
            <div class="col-12 mb-5">
                <h2 class="mb-3 text-center">{{ __('main.faq') }}</h2>
                <p class="text-center bl-text-small mt-3">{{ __('main.faqInfo') }}</p>
                <div class="accordion" id="accordionExample">
                    <div class="card accordion-item mb-2">
                        <h2 class="card-header p-0 ">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseOne" aria-expanded="false" aria-controls="collapseOne">
                               {{ __('main.silverThirdQMain') }}
                            </button>
                        </h2>
                        <div id="collapseOne" class="accordion-collapse collapse" data-bs-parent="#accordionExample">
                            <div class="card-body">
                                {{ __('main.silverThirdAnswerMain', ['today' => $currentDay, 'price' => priceFormat($metalPriceEgp->price, 2)]) }}
                            </div>
                        </div>
                    </div>
                    <div class="card accordion-item mb-2">
                        <h2 class="card-header p-0 ">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
                                {{ __('main.silverFirstQ') }}
                            </button>
                        </h2>
                        <div id="collapseThree" class="accordion-collapse collapse" data-bs-parent="#accordionExample">
                            <div class="card-body">
                                {{ __('main.silverFirstAnswer') }}
                            </div>
                        </div>
                    </div>
                    <div class="card accordion-item mb-2">
                        <h2 class="card-header p-0 ">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseTwo" aria-controls="collapseTwo">
                                {{ __('main.silverSecondQ') }}
                            </button>
                        </h2>
                        <div id="collapseTwo" class="accordion-collapse collapse" data-bs-parent="#accordionExample">
                            <div class="card-body">
                                {{ __('main.silverSecondAnswer') }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </div>
    </div>
@endsection
